#
# spec file for package libvirt
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

# The hypervisor drivers that run in libvirtd
%define with_xen           0%{!?_without_xen:1}
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_uml           0%{!?_without_uml:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_phyp          0%{!?_without_phyp:0}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:0}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd   0%{!?_without_storage_rbd:0}
%define with_storage_sheepdog 0
%define with_storage_gluster  0
%define with_apparmor      0%{!?_without_apparmor:1}

# Optional bits on by default
%define with_sanlock       0%{!?_without_sanlock:1}
%define with_polkit_rules  1
%define with_wireshark     0%{!?_without_wireshark:1}

# A few optional bits off by default, we enable later
%define with_cgconfig      0%{!?_without_cgconfig:0}
%define with_numactl       0%{!?_without_numactl:0}
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld     0%{!?_without_firewalld:0}
%define with_libssh        0%{!?_without_libssh:0}
%define with_bash_completion 0%{!?_without_bash_completion:0}

# Xen no longer contains xm/xend so disable building the legacy Xen driver
%define with_xen           0

# Set the OS / architecture specific special cases

# Xen is available only on x86_64, armv7 and aarch64
%ifnarch x86_64 armv7hl aarch64
    %define with_xen       0
    %define with_libxl     0
%endif

# For SLE, further restrict Xen support to x86_64 only
%if ! 0%{?is_opensuse}
    %ifarch %arm aarch64
        %define with_xen   0
        %define with_libxl 0
    %endif
%endif

# Enable numactl for most architectures. Handle aarch64 separately
%ifnarch s390 s390x %arm %ix86 aarch64
    %define with_numactl   0%{!?_without_numactl:1}
%endif

# For aarch64, numactl is only available on newer than 1320, or SLE12
# family newer than 120100
%ifarch aarch64
    %if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && ( 0%{?sle_version} > 120100 ) )
        %define with_numactl 0%{!?_without_numactl:1}
    %endif
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox      0
%endif

# Disable hypervisor drivers not supported in SLE
%if ! 0%{?is_opensuse}
    %define with_openvz    0
    %define with_vbox      0
    %define with_uml       0
    %define with_vmware    0
    %define with_hyperv    0
%endif

# Enable phyp driver for IBM Power systems
%ifarch ppc64
    %define with_phyp      1
%endif

# Enable firewalld support in newer code bases
%if 0%{?suse_version} >= 1500
    %define with_firewalld 1
%endif

# TODO: On what distros can we support bash-completion?
#       SLE12 builds seem fine, but configure fails to detect
#       completion support on openSUSE distros.
%define with_bash_completion  0%{!?_without_bash_completion:0}

# rbd enablement is a bit tricky. For x86_64
%ifarch x86_64
# enable on anything newer than 1320, or SLE12 family newer than 120100
# use librbd-devel as build dependency
    %if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && ( 0%{?sle_version} > 120100 ) )
        %define with_storage_rbd 0%{!?_without_storage_rbd:1}
        %define with_rbd_lib     librbd-devel
    %endif
# enable for SLE12 family <= 120100 (SLE12GA/SP1, Leap 42.1)
# use ceph-devel as build dependency
    %if 0%{?suse_version} == 1315 && 0%{?sle_version} <= 120100
        %define with_storage_rbd 0%{!?_without_storage_rbd:1}
        %define with_rbd_lib     ceph-devel
    %endif
%endif

# For arm
%ifarch aarch64
# enable on anything newer than 1320, or SLE12 newer than 120100
# use librbd-devel as build dependency
    %if 0%{?suse_version} > 1320 || ( 0%{?is_opensuse} == 0 && 0%{?sle_version} > 120100 )
        %define with_storage_rbd 0%{!?_without_storage_rbd:1}
        %define with_rbd_lib     librbd-devel
    %endif
%endif

# numad is used to manage the CPU and memory placement dynamically for
# qemu, lxc, and uml drivers
%if %{with_qemu} || %{with_lxc} || %{with_uml}
# Enable numad for most architectures. Handle aarch64 separately
    %ifnarch s390 s390x %arm %ix86 aarch64
        %define with_numad 0%{!?_without_numad:1}
    %endif
# For aarch64, enable on anything newer than 1320, or SLE12 family newer
# than 120100
    %ifarch aarch64
        %if 0%{?suse_version} > 1320 || ( 0%{?suse_version} == 1315 && 0%{?sle_version} > 120100 )
            %define with_numad 0%{!?_without_numad:1}
        %endif
    %endif
%endif

# Force QEMU to run as qemu:qemu
%define qemu_user          qemu
%define qemu_group         qemu

# Pull in cgroups config system
%if %{with_qemu} || %{with_lxc}
    %define with_cgconfig  0%{!?_without_cgconfig:1}
%endif

%if %{with_firewalld}
    %define _fwdefdir %{_libexecdir}/firewalld/services
%else
    %define _fwdefdir /etc/sysconfig/SuSEfirewall2.d/services
%endif

Name:           libvirt
Url:            http://libvirt.org/
Version:        4.0.0
Release:        lp150.7.18.3
Summary:        Library providing a simple virtualization API
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-config-network = %{version}-%{release}
Requires:       %{name}-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires:       %{name}-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_lxc}
Requires:       %{name}-daemon-driver-lxc = %{version}-%{release}
%endif
%if %{with_qemu}
Requires:       %{name}-daemon-driver-qemu = %{version}-%{release}
%endif
%if %{with_uml}
Requires:       %{name}-daemon-driver-uml = %{version}-%{release}
%endif
%if %{with_xen}
Requires:       %{name}-daemon-driver-xen = %{version}-%{release}
%endif
%if %{with_vbox}
Requires:       %{name}-daemon-driver-vbox = %{version}-%{release}
%endif
Requires:       %{name}-client = %{version}-%{release}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-tools
BuildRequires:  libtool
# Needed for virkmodtest in 'make check'
BuildRequires:  modutils
BuildRequires:  systemd
BuildRequires:  pkgconfig(systemd)
%if %{with_xen} || %{with_libxl}
BuildRequires:  xen-devel
%endif
%if %{with_qemu}
# For managing ACLs
BuildRequires:  libacl-devel
%endif
%if %{with_bash_completion}
BuildRequires:  bash-completion >= 2.0
%endif
BuildRequires:  fdupes
BuildRequires:  libattr-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libtasn1-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  python3
BuildRequires:  readline-devel
# perl XPath is needed since we have a patch touching files that cause
# hvsupport.html to be regenerated
BuildRequires:  perl(XML::XPath)
# For pool-build probing for existing pools
BuildRequires:  libblkid-devel >= 2.17
BuildRequires:  libpciaccess0-devel >= 0.10.9
BuildRequires:  libudev-devel >= 145
BuildRequires:  libyajl-devel
%if %{with_sanlock}
BuildRequires:  sanlock-devel >= 2.4
%endif
BuildRequires:  libavahi-devel
BuildRequires:  libnl3-devel
BuildRequires:  libpcap-devel
BuildRequires:  libselinux-devel
%if 0%{?suse_version} >= 1330
BuildRequires:  libtirpc-devel
%endif
%if %{with_apparmor}
%if 0%{?suse_version} >= 1500
BuildRequires:  apparmor-rpm-macros
%endif
BuildRequires:  libapparmor-devel
%endif
BuildRequires:  dnsmasq >= 2.41
BuildRequires:  iptables
# TODO BuildRequires:  iptables-ipv6
BuildRequires:  cyrus-sasl-devel
BuildRequires:  ebtables
BuildRequires:  polkit >= 0.93
BuildRequires:  polkit-devel >= 0.93
BuildRequires:  radvd
# For mount/umount in FS driver
BuildRequires:  util-linux
# For LVM drivers
BuildRequires:  lvm2
# For ISCSI driver
BuildRequires:  open-iscsi
# For disk driver
BuildRequires:  parted-devel
# For Multipath support
BuildRequires:  device-mapper-devel
%if %{with_storage_rbd}
BuildRequires:  %{with_rbd_lib}
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires:  libnuma-devel
%endif
BuildRequires:  fuse-devel >= 2.8.6
BuildRequires:  libcap-ng-devel >= 0.5.0
BuildRequires:  libnetcontrol-devel >= 0.2.0
BuildRequires:  libssh2-devel
%if %{with_esx}
BuildRequires:  libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires:  libwsman-devel >= 2.2.3
%endif
BuildRequires:  audit-devel
# we need /usr/sbin/dtrace
BuildRequires:  systemtap-sdt-devel
%if %{with_numad}
BuildRequires:  numad
%endif
%if %{with_wireshark}
BuildRequires:  wireshark-devel >= 2.1.0
%endif
%if %{with_libssh}
BuildRequires:  libssh-devel >= 0.7.0
%endif
%if %{with_firewalld}
BuildRequires:  firewall-macros
%endif

Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        libvirtd-relocation-server.fw
Source4:        libvirt-supportconfig
Source5:        suse-qemu-domain-hook.py
Source6:        libvirtd-relocation-server.xml
Source99:       baselibs.conf
Source100:      %{name}-rpmlintrc
# Upstream patches
Patch0:         72adaf2f-revert-qemu-monitor-error-report.patch
Patch1:         71d56a39-nodedev-fix-parse-PCI-address.patch
Patch2:         68eed56b-conf-smbios-oem-strings.patch
Patch3:         76977061-qemu-smbios-oem-strings.patch
Patch4:         0c710a37-libxl-resume-lock-on-mig-failure.patch
Patch5:         6b3d716e-keycodemap-py3.patch
Patch6:         759b4d1b-virlog-determine-the-hostname-on-startup-CVE-2018-67.patch
Patch7:         c2dc6698-fix-deadlock-obtaining-hostname.patch
Patch8:         c391e07e-libxl-clock-settings.patch
Patch9:         ef71caea-libxl-memalign.patch
Patch10:        1b0c42ff-libvirtd-depend-machined.patch
Patch11:        33c6eb96-fix-libvirtd-reload-deadlock.patch
Patch12:        464889ff-rpc-aquire-ref-dispatch.patch
Patch13:        c6f1d519-rpc-simplify-dispatch.patch
Patch14:        06e7ebb6-rpc-invoke-dispatch-unlocked.patch
Patch15:        86cae503-rpc-fix-pre-exec.patch
Patch16:        eefabb38-rpc-virtlockd-virtlogd-single-thread.patch
Patch17:        fbf31e1a-CVE-2018-1064.patch
Patch18:        64370c4b-libxl-MigrateBegin.patch
Patch19:        99486799-libxl-MigrateConfirm.patch
Patch20:        f5eacf2a-libxl-MigratePerform.patch
Patch21:        4e6fcdb6-libxl-libxlDomObjFromDomain-cleanup.patch
Patch22:        fe51dbda-libxl-use-FindByRef.patch
Patch23:        60b3fcd9-libxl-MigratePrepare.patch
Patch24:        3c89868c-libxl-lock-after-ListRemove.patch
Patch25:        13e81fc6-libxl-EndJob-on-error.patch
Patch26:        594b8b99-libxl-DefineXMLFlags-API-pattern.patch
Patch27:        c66e344e-libxl-dont-deref-NULL.patch
Patch28:        83edaf44-libxl-dont-hardcode-sched-weight.patch
Patch29:        09877303-virSocketAddrParseInternal.patch
Patch30:        412afdb8-intro-virSocketAddrParseAny.patch
Patch31:        1dbca2ec-CVE-2018-3639.patch
Patch32:        92673422-CVE-2018-3639.patch
Patch33:        ac4a12db-libxl-fix-hasManagedSave.patch
Patch34:        67c56f6e-libxl-logfd-leak-fix.patch
Patch35:        4d7384eb-dont-check-parallel-iteration-hash-func.patch
Patch36:        60b4fd90-libxl-rm-vm-finish-phase.patch
Patch37:        e39c66d3-libxl-fix-p2p-migration.patch
Patch38:        47da84e0-libxl-fix-job-handling-migsrc.patch
Patch39:        0149464a-libxl-fix-job-handling-migdst.patch
Patch40:        5ea2abb3-libxl-join-mig-rcv-thread.patch
Patch41:        d4005609-qemu-query-sev-caps.patch
Patch42:        5dca09c1-expose-sev-domcaps.patch
Patch43:        45422935-intro-virNodeGetSEVInfo-API.patch
Patch44:        e4db4daf-remote-virNodeGetSEVInfo.patch
Patch45:        6596ac42-backend-virNodeGetSEVInfo.patch
Patch46:        e5791a03-intro-launch-security.patch
Patch47:        a9caa981-add-sev-shared-dev.patch
Patch48:        11ab77fe-support-launch-sev-guest.patch
Patch49:        077c9a25-intro-virDomainGetLaunchSecurityInfo-API.patch
Patch50:        a12278a1-remote-launch-security.patch
Patch51:        bfaa61c8-backend-virDomainGetLaunchSecurityInfo.patch
Patch52:        a95b99d0-rename-reducedPhysBits.patch
Patch53:        e56ff8bc-prefer-camelCase-launchSecurity.patch
Patch54:        dfc56964-remove-virQEMUCapsSetSEVCapabilities.patch
Patch55:        2382a236-fix-qemuDomainGetSEVMeasurement-leak.patch
Patch56:        2555749f-rename-qemuBuildSevCreateFile.patch
Patch57:        6718132d-use-cleanup-qemuProcessSEVCreateFile.patch
Patch58:        6b90f4bb-rename-virDomainSevDefPtr.patch
Patch59:        6bbb35ee-rename-sev-funcs.patch
Patch60:        c92c6cd2-qemuBuildSevCommandLine.patch
Patch61:        84e4046c-fix-leak-qemuBuildSevCommandLine.patch
Patch62:        4817687a-rework-virDomainSEVDefParseXML.patch
Patch63:        a349c6c2-ignore-query-sev-capabilities-errors.patch
Patch64:        6688393c-fix-sev-element-formatting.patch
Patch65:        54c54b56-sev-use-EnterMonitor.patch
Patch66:        6d490ed0-fix-sev-endjob.patch
Patch67:        e039a830-fix-qemuProcessSEVCreateFile-retval.patch
Patch68:        764491c9-qemu-fix-probing-sev-support.patch
Patch69:        77f51ab5-qemu-caps-format-sev-platform-data.patch
Patch70:        cc786a8f-qemu-free-sev-caps.patch
Patch71:        14d03b27-libxl-rm-redundant-virObjectEventStateQueue.patch
Patch72:        82452a5d-libxl-rm-goto-libxlDomainShutdownThread.patch
Patch73:        da4b0fd9-libxl-support-soft-reset.patch
Patch74:        8741b943-apparmor-ptrace-rules.patch
Patch75:        11c8aca9-libxl-set-mem-after-balloon.patch
Patch76:        70c2933d-apparmor-named-profiles.patch
Patch77:        b6440119-qemu-conf-sev.patch
Patch78:        a404ac34-qemu-cgroup-sev.patch
Patch79:        6fd4c8f8-qemu-domain-sev.patch
Patch80:        17f6a257-security-dac-sev.patch
Patch81:        a2d3dea9-qemu-caps-dac-override-sev.patch
Patch82:        620d9dd5-qemu-no-dac-override-nonroot.patch
Patch83:        7cfd1fbb-qemu-CVE-2019-3840.patch
Patch84:        f38ef0fa-no-RDMA-check.patch
Patch85:        09eb1ae0-conf-add-xenbus-controller.patch
Patch86:        fb059757-libxl-add-xenbus-controller.patch
Patch87:        ec5a1191-libxl-support-max-grant-frames.patch
Patch88:        5a64c202-xenconfig-support-max-grant-frames.patch
Patch89:        CVE-2019-3886-api.patch
Patch90:        CVE-2019-3886-remote.patch
Patch91:        5cd9db3a-cputest-add-data-E3-1225-v5.patch
Patch92:        538d8735-cpu_map-Define-md-clear-CPUID-bit.patch
Patch93:        4cb90fa2-4-1-maint-branch-remove-stibp-from-tests.patch
Patch94:        CVE-2019-10161-api-disallow-virDomainSaveImageGetXMLDesc.patch
Patch95:        CVE-2019-10166-api-disallow-virDomainManagedSaveDefineXML.patch
Patch96:        CVE-2019-10167-api-disallow-virConnectGetDomainCapabilities.patch
# Patches pending upstream review
Patch100:       libxl-dom-reset.patch
Patch101:       network-don-t-use-dhcp-authoritative-on-static-netwo.patch
# Need to go upstream
Patch150:       xen-pv-cdrom.patch
Patch151:       blockcopy-check-dst-identical-device.patch
Patch152:       libvirt-power8-models.patch
Patch153:       ppc64le-canonical-name.patch
Patch154:       libxl-set-migration-constraints.patch
Patch155:       libxl-set-cach-mode.patch
Patch156:       0001-Extract-stats-functions-from-the-qemu-driver.patch
Patch157:       0002-lxc-implement-connectGetAllDomainStats.patch
Patch158:       apibuild-py3.patch
Patch159:       0001-libxl-add-support-for-BlockResize-API.patch
# Our patches
Patch200:       suse-libvirtd-disable-tls.patch
Patch201:       suse-libvirtd-sysconfig-settings.patch
Patch202:       suse-libvirt-guests-service.patch
Patch203:       suse-virtlockd-sysconfig-settings.patch
Patch204:       suse-virtlogd-sysconfig-settings.patch
Patch205:       suse-libvirtd-service-xen.patch
Patch206:       suse-qemu-conf.patch
Patch207:       suse-ovmf-paths.patch
Patch208:       suse-apparmor-libnl-paths.patch
Patch209:       suse-apparmor-signal.patch
Patch210:       support-managed-pci-xen-driver.patch
Patch211:       xen-sxpr-disk-type.patch
Patch212:       libxl-support-block-script.patch
Patch213:       qemu-apparmor-screenshot.patch
Patch214:       libvirt-suse-netcontrol.patch
Patch215:       lxc-wait-after-eth-del.patch
Patch216:       libxl-qemu-emulator-caps.patch
# SLES-Only patches
%if ! 0%{?is_opensuse}
Patch400:       virt-create-rootfs.patch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libvirt is a C toolkit to interact with the virtualization
capabilities of Linux. Virtualization of the Linux Operating System means
the ability to run multiple instances of Operating Systems concurrently
on a single hardware system where the basic resources are driven by a
Linux instance. The library aims to provide long term stable C API
to interact with Linux virtualization technologies.

%package doc
Summary:        API reference and website documentation for libvirt
Group:          Documentation/HTML

%description doc
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary:        Server side daemon and supporting files for libvirt
Group:          Development/Libraries/C and C++

# All runtime requirements for the libvirt package (runtime requirements
# for subpackages are listed later in those subpackages)

Requires:       %{name}-libs = %{version}-%{release}

# for modprobe of pci devices
Requires:       modutils
# for /sbin/ip & /sbin/tc
Requires:       iproute
Requires:       logrotate
Requires:       udev >= 145
Recommends:     polkit >= 0.93
%ifarch i386 i586 i686 x86_64 ia64
# For virConnectGetSysinfo
Requires:       dmidecode
%endif
# For service management
%{?systemd_requires}
%if %{with_numad}
Requires:       numad
%endif

# libvirt is configured with paths to UEFI firmwares in %build,
# hence add a dependency to the firmware packages
%ifarch x86_64
Requires:       qemu-ovmf-x86_64
%endif
%ifarch aarch64
Requires:       qemu-uefi-aarch64
%endif

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-hooks
Summary:        Hook scripts for the libvirtd daemon
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       python3-lxml

%description daemon-hooks
Default hook scripts for the libvirt daemon

%package daemon-config-network
Summary:        Default configuration files for the libvirtd daemon
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary:        Network filter configuration files for the libvirtd
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for the libvirt daemon, used for
cleaning guest network traffic.

%package daemon-driver-network
Summary:        Network driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       dnsmasq >= 2.41
Requires:       iptables
# TODO Requires:       iptables-ipv6
Requires:       %{name}-daemon = %{version}-%{release}
Requires:       radvd

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.

%package daemon-driver-nwfilter
Summary:        A nwfilter driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       ebtables
Requires:       iptables
# TODO Requires:       iptables-ipv6
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities

%package daemon-driver-nodedev
Summary:        Nodedev driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.

%package daemon-driver-interface
Summary:        Interface driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcontrol library

%package daemon-driver-secret
Summary:        Secret driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.

%package daemon-driver-storage-core
Summary:        Storage driver plugin including base backends for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}
Requires:       nfs-utils
# For mkfs
Requires:       util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires:       /usr/bin/qemu-img
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%package daemon-driver-storage-logical
Summary:        Storage driver plugin for lvm volumes
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.

%package daemon-driver-storage-disk
Summary:        Storage driver plugin for disk
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       device-mapper
Requires:       parted

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.

%package daemon-driver-storage-scsi
Summary:        Storage driver plugin for local scsi devices
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.

%package daemon-driver-storage-iscsi
Summary:        Storage driver plugin for iscsi
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       open-iscsi

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.

%package daemon-driver-storage-mpath
Summary:        Storage driver plugin for multipath volumes
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary:        Storage driver plugin for gluster
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif

%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary:        Storage driver plugin for rbd
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif

%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary:        Storage driver plugin for sheepdog
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif

%package daemon-driver-storage
Summary:        Storage driver plugin including all backends for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-disk = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-iscsi = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-logical = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-mpath = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-scsi = %{version}-%{release}
%if %{with_storage_gluster}
Requires:       %{name}-daemon-driver-storage-gluster = %{version}-%{release}
%endif
%if %{with_storage_rbd}
Requires:       %{name}-daemon-driver-storage-rbd = %{version}-%{release}
%endif
%if %{with_storage_sheepdog}
Requires:       %{name}-daemon-driver-storage-sheepdog = %{version}-%{release}
%endif

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.

%if %{with_qemu}

%package daemon-driver-qemu
Summary:        Qemu driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage-core = %{version}-%{release}
Requires:       /usr/bin/qemu-img
# For image compression
Requires:       bzip2
Requires:       gzip
Requires:       lzop
Requires:       qemu
Requires:       xz
Requires:       systemd-container

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using QEMU.
%endif

%if %{with_lxc}

%package daemon-driver-lxc
Summary:        LXC driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       systemd-container

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif

%if %{with_uml}

%package daemon-driver-uml
Summary:        Uml driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-uml
The UML driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
User Mode Linux
%endif

%if %{with_xen}

%package daemon-driver-xen
Summary:        Xen driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-xen
The Xen driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using Xen.
%endif

%if %{with_vbox}

%package daemon-driver-vbox
Summary:        VirtualBox driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif

%if %{with_libxl}

%package daemon-driver-libxl
Summary:        Libxl driver plugin for the libvirtd daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using libxl.
%endif

%if %{with_qemu}

%package daemon-qemu
Summary:        Server side daemon & driver required to run QEMU guests
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-qemu = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU emulators
%endif

%if %{with_lxc}

%package daemon-lxc
Summary:        Server side daemon & driver required to run LXC guests
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
Requires:       %{name}-daemon-driver-lxc = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif

%if %{with_uml}

%package daemon-uml
Summary:        Server side daemon & driver required to run UML guests
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       %{name}-daemon-driver-uml = %{version}-%{release}

%description daemon-uml
Server side daemon and driver required to manage the virtualization
capabilities of UML
%endif

%if %{with_xen} || %{with_libxl}

%package daemon-xen
Summary:        Server side daemon & driver required to run XEN guests
Group:          Development/Libraries/C and C++

Requires:       %{name}-daemon = %{version}-%{release}
    %if %{with_xen}
Requires:       %{name}-daemon-driver-xen = %{version}-%{release}
    %endif
    %if %{with_libxl}
Requires:       %{name}-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}

%package daemon-vbox
Summary:        Server side daemon & driver required to run VirtualBox guests
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-daemon-driver-interface = %{version}-%{release}
Requires:       %{name}-daemon-driver-network = %{version}-%{release}
Requires:       %{name}-daemon-driver-nodedev = %{version}-%{release}
Requires:       %{name}-daemon-driver-nwfilter = %{version}-%{release}
Requires:       %{name}-daemon-driver-secret = %{version}-%{release}
Requires:       %{name}-daemon-driver-storage = %{version}-%{release}
Requires:       %{name}-daemon-driver-vbox = %{version}-%{release}
# Specify supported virtualbox API explicitly. See ./src/vbox
# Reference bsc#1017189 
Requires:       virtualbox < 5.3

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%package client
Summary:        Client side utilities of the libvirt library
Group:          Development/Libraries/C and C++
Requires:       %{name}-libs = %{version}-%{release}
Requires:       ncurses
Requires:       readline
# Needed by libvirt-guests init script.
Requires:       gettext-runtime
# Needed by virt-pki-validate script.
Requires:       cyrus-sasl
Requires:       gnutls

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary:        Client side libraries for libvirt
# So remote clients can access libvirt over SSH tunnel
# (client invokes 'nc' against the UNIX socket on the server)
Group:          Development/Libraries/C and C++
Requires:       netcat-openbsd
# Not technically required, but makes 'out-of-box' config
# work correctly & doesn't have onerous dependencies
Requires:       cyrus-sasl-digestmd5

%description libs
Shared libraries for accessing the libvirt daemon.

%package admin
Summary:        Set of tools to control libvirt daemon
Group:          Development/Libraries/C and C++
Requires:       %{name}-libs = %{version}-%{release}
Requires:       readline

%description admin
The client side utilities to control the libvirt daemon.

%package devel
Summary:        Libraries, includes, etc. to compile with the libvirt library
Group:          Development/Libraries/C and C++
Requires:       %{name}-client = %{version}-%{release}
Requires:       %{name}-doc = %{version}-%{release}
Requires:       pkg-config

%description devel
Include header files & development libraries for the libvirt C library.


%if %{with_sanlock}

%package lock-sanlock
Summary:        Sanlock lock manager plugin for QEMU driver
Group:          Development/Libraries/C and C++
Requires:       sanlock >= 2.4
# for virt-sanlock-cleanup require augeas
Requires:       %{name}-daemon = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}
Requires:       augeas

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU driver
%endif

%if %{with_wireshark}

%package -n wireshark-plugin-libvirt
Summary:        Wireshark plugin for libvirt RPC protocol
Group:          Productivity/Networking/Diagnostic
Requires:       %{name}-libs = %{version}-%{release}
Requires:       wireshark

%description -n wireshark-plugin-libvirt
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%package nss
Summary:        Libvirt plugin for Name Service Switch
Group:          Development/Libraries/C and C++
Requires:       %{name}-daemon-driver-network = %{version}-%{release}

%description nss
libvirt plugin for NSS for translating domain names into IP addresses.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
# it is submodule in git
pushd src/keycodemapdb
%patch5 -p1
popd
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%patch46 -p1
%patch47 -p1
%patch48 -p1
%patch49 -p1
%patch50 -p1
%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1
%patch55 -p1
%patch56 -p1
%patch57 -p1
%patch58 -p1
%patch59 -p1
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%patch68 -p1
%patch69 -p1
%patch70 -p1
%patch71 -p1
%patch72 -p1
%patch73 -p1
%patch74 -p1
%patch75 -p1
%patch76 -p1
%patch77 -p1
%patch78 -p1
%patch79 -p1
%patch80 -p1
%patch81 -p1
%patch82 -p1
%patch83 -p1
%patch84 -p1
%patch85 -p1
%patch86 -p1
%patch87 -p1
%patch88 -p1
%patch89 -p1
%patch90 -p1
%patch91 -p1
%patch92 -p1
%patch93 -p1
%patch94 -p1
%patch95 -p1
%patch96 -p1
%patch100 -p1
%patch101 -p1
%patch150 -p1
%patch151 -p1
%patch152 -p1
%patch153 -p1
%patch154 -p1
%patch155 -p1
%patch156 -p1
%patch157 -p1
%patch158 -p1
%patch159 -p1
%patch200 -p1
%patch201 -p1
%patch202 -p1
%patch203 -p1
%patch204 -p1
%patch205 -p1
%patch206 -p1
%patch207 -p1
%patch208 -p1
%patch209 -p1
%patch210 -p1
%patch211 -p1
%patch212 -p1
%patch213 -p1
%patch214 -p1
%patch215 -p1
%patch216 -p1
%if ! 0%{?is_opensuse}
%patch400 -p1
%endif

%build
%if %{with_xen}
    %define arg_xen --with-xen
%else
    %define arg_xen --without-xen
%endif
%if %{with_qemu}
    %define arg_qemu --with-qemu
%else
    %define arg_qemu --without-qemu
%endif
%if %{with_openvz}
    %define arg_openvz --with-openvz
%else
    %define arg_openvz --without-openvz
%endif
%if %{with_lxc}
    %define arg_lxc --with-lxc
%else
    %define arg_lxc --without-lxc
%endif
%if %{with_vbox}
    %define arg_vbox --with-vbox
%else
    %define arg_vbox --without-vbox
%endif
%if %{with_uml}
    %define arg_uml --with-uml
%else
    %define arg_uml --without-uml
%endif
%if %{with_phyp}
    %define arg_phyp --with-phyp
%else
    %define arg_phyp --without-phyp
%endif
%if %{with_esx}
    %define arg_esx --with-esx
%else
    %define arg_esx --without-esx
%endif
%if %{with_vmware}
    %define arg_vmware --with-vmware
%else
    %define arg_vmware --without-vmware
%endif
%if %{with_hyperv}
    %define arg_hyperv --with-hyperv
%else
    %define arg_hyperv --without-hyperv
%endif
%if %{with_libxl}
    %define arg_libxl --with-libxl
%else
    %define arg_libxl --without-libxl
%endif
%if %{with_storage_rbd}
    %define arg_storage_rbd --with-storage-rbd
%else
    %define arg_storage_rbd --without-storage-rbd
%endif
%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog --with-storage-sheepdog
%else
    %define arg_storage_sheepdog --without-storage-sheepdog
%endif
%if %{with_storage_gluster}
    %define arg_storage_gluster --with-storage-gluster
%else
    %define arg_storage_gluster --without-storage-gluster
%endif
%if %{with_numactl}
    %define arg_numactl --with-numactl
%else
    %define arg_numactl --without-numactl
%endif
%if %{with_numad}
    %define arg_numad --with-numad
%else
    %define arg_numad --without-numad
%endif
%if %{with_apparmor}
    %define arg_apparmor --with-apparmor
    %define arg_apparmor_profiles --with-apparmor-profiles
%else
    %define arg_apparmor --without-apparmor
%endif
%if %{with_sanlock}
    %define arg_sanlock --with-sanlock
%else
    %define arg_sanlock --without-sanlock
%endif
%if %{with_firewalld}
    %define arg_firewalld --with-firewalld
%else
    %define arg_firewalld --without-firewalld
%endif
%if %{with_wireshark}
    %define arg_wireshark --with-wireshark-dissector
%else
    %define arg_wireshark --without-wireshark-dissector
%endif

%define arg_selinux_mount --with-selinux-mount="/selinux"

# x86_64 UEFI firmwares
# To more closely resemble actual hardware, we use the firmwares with
# embedded Microsoft keys
#
# The Windows HCK test requires a bigger variable store, so 4MB firmware
# images have been introduced. They are advertised first and will be
# used by default for new VM installations. The 2MB images are still
# available for existing VMs, and can be selected for new installations
# as well.
LOADERS="/usr/share/qemu/ovmf-x86_64-ms-4m-code.bin:/usr/share/qemu/ovmf-x86_64-ms-4m-vars.bin"
LOADERS="$LOADERS:/usr/share/qemu/ovmf-x86_64-ms-code.bin:/usr/share/qemu/ovmf-x86_64-ms-vars.bin"
# aarch64 UEFI firmwares
LOADERS="$LOADERS:/usr/share/qemu/aavmf-aarch64-code.bin:/usr/share/qemu/aavmf-aarch64-vars.bin"
%define arg_loader_nvram --with-loader-nvram="$LOADERS"

autoreconf -f -i
export CFLAGS="%{optflags}"
export PYTHON=%{_bindir}/python3
%configure --disable-static \
           %{?arg_xen} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           --with-sasl \
           --with-avahi \
           --with-polkit \
           --with-libvirtd \
           %{?arg_uml} \
           %{?arg_phyp} \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           --without-xenapi \
           --without-vz \
           --without-bhyve \
           --with-interface \
           --with-network \
           --with-storage-fs \
           --with-storage-lvm \
           --with-storage-iscsi \
           --with-storage-scsi \
           --with-storage-disk \
           --with-storage-mpath \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           --without-storage-zfs \
           --without-storage-vstorage \
           %{?arg_numactl} \
           %{?arg_numad} \
           --with-capng \
           --with-fuse \
           --without-netcf \
           --with-netcontrol \
           --with-selinux \
           %{?arg_selinux_mount} \
           %{?arg_apparmor} \
           %{?arg_apparmor_profiles} \
           --with-udev \
           --with-yajl \
           %{?arg_sanlock} \
           --with-libpcap \
           --with-macvtap \
           --with-audit \
           --with-dtrace \
           --with-driver-modules \
           %{?arg_firewalld} \
           %{?arg_wireshark} \
           --with-nss-plugin \
           --libexecdir=%{_libdir}/%{name} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           %{?arg_loader_nvram} \
           --without-login-shell \
           --with-init-script=systemd \
           ac_cv_path_MODPROBE=/sbin/modprobe \
           ac_cv_path_UDEVADM=/sbin/udevadm \
           ac_cv_path_SHOWMOUNT=/usr/sbin/showmount \
           ac_cv_path_PARTED=/usr/sbin/parted \
           ac_cv_path_QEMU_BRIDGE_HELPER=/usr/lib/qemu-bridge-helper
make V=1 %{?_smp_mflags} HTML_DIR=%{_docdir}/%{name}
gzip -9 ChangeLog

%install
%make_install SYSTEMD_UNIT_DIR=%{_unitdir} HTML_DIR=%{_docdir}/%{name}
make %{?_smp_mflags} -C examples distclean
cp examples/lxcconvert/virt-lxc-convert %{buildroot}/%{_bindir}
rm -f %{buildroot}/%{_libdir}/*.la
%if %{with_wireshark}
rm -f %{buildroot}/%{_libdir}/wireshark/plugins/*/libvirt.la
%endif
rm -f %{buildroot}/%{_libdir}/*.a
rm -f %{buildroot}/%{_libdir}/%{name}/lock-driver/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/lock-driver/*.a
rm -f %{buildroot}/%{_libdir}/%{name}/connection-driver/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/connection-driver/*.a
rm -f %{buildroot}/%{_libdir}/%{name}/storage-backend/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/storage-backend/*.a
# remove currently unsupported locale(s)
for dir in %{buildroot}/usr/share/locale/*
do
  sdir=`echo $dir | sed "s|%{buildroot}||"`
  if test -d $sdir ; then continue ; fi
  rm -rfv "$dir"
done

mkdir -p %{buildroot}/%{_localstatedir}/lib/libvirt
mkdir -p %{buildroot}/%{_sysconfdir}/libvirt/hooks
%find_lang %{name}
# Add a README to the libvirt package with a note about the empty
# file list
cat > %{buildroot}/%{_docdir}/libvirt/libvirt.README << 'EOF'
The libvirt package no longer contains any files.  It exists now
only to fulfill its 'Provides' contract.
EOF
install -d -m 0755 %{buildroot}/%{_localstatedir}/lib/libvirt/dnsmasq/
install -d -m 0755 %{buildroot}/%{_datadir}/libvirt/networks/
cp %{buildroot}/%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   %{buildroot}/%{_datadir}/libvirt/networks/default.xml
rm -f %{buildroot}/%{_sysconfdir}/libvirt/qemu/networks/default.xml
rm -f %{buildroot}/%{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" %{buildroot}/%{_datadir}/libvirt/networks/default.xml
%if %{with_lxc}
cat > %{buildroot}/%{_docdir}/libvirt/libvirt-daemon-lxc.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing LXC.
EOF
%else
rm -rf %{buildroot}/%{_sysconfdir}/libvirt/lxc.conf
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
rm -rf %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if %{with_qemu}
cat > %{buildroot}/%{_docdir}/libvirt/libvirt-daemon-qemu.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing QEMU/KVM.
EOF
%else
rm -rf %{buildroot}/%{_sysconfdir}/libvirt/qemu.conf
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
rm -rf %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.qemu
%endif
%if %{with_uml}
cat > %{buildroot}/%{_docdir}/libvirt/libvirt-daemon-uml.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing UML.
EOF
%else
rm -rf %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.uml
%endif
%if %{with_vbox}
cat > %{buildroot}/%{_docdir}/libvirt/libvirt-daemon-vbox.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing VirtualBox.
EOF
%endif
%if %{with_xen} || %{with_libxl}
cat > %{buildroot}/%{_docdir}/libvirt/libvirt-daemon-xen.README << 'EOF'
Any empty package encapsulating requirements for a libvirtd capable
of managing Xen.
EOF
%endif
%if ! %{with_libxl}
rm -f %{buildroot}/%{_sysconfdir}/libvirt/libxl.conf
rm -f %{buildroot}/%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif
%if ! %{with_sanlock}
rm -f %{buildroot}/%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f %{buildroot}/%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

# init scripts
mkdir -p %{buildroot}/%{_fillupdir}
rm -f %{buildroot}/usr/lib/sysctl.d/60-libvirtd.conf
mv %{buildroot}/%{_sysconfdir}/sysconfig/libvirtd %{buildroot}%{_fillupdir}/sysconfig.libvirtd
mv %{buildroot}/%{_sysconfdir}/sysconfig/virtlogd %{buildroot}/%{_fillupdir}/sysconfig.virtlogd
mv %{buildroot}/%{_sysconfdir}/sysconfig/virtlockd %{buildroot}/%{_fillupdir}/sysconfig.virtlockd
mv %{buildroot}/%{_sysconfdir}/sysconfig/libvirt-guests %{buildroot}/%{_fillupdir}/sysconfig.libvirt-guests
# Provide rc symlink backward compatibility
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rclibvirtd
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcvirtlogd
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcvirtlockd
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rclibvirt-guests

# install firewall services for migration ports
mkdir -p %{buildroot}/%{_fwdefdir}
%if %{with_firewalld}
install -m 644 %{S:6} %{buildroot}/%{_fwdefdir}/libvirtd-relocation-server.xml
%else
# Format described in /usr/share/SuSEfirewall2/services/TEMPLATE
install -m 644 %{S:3} %{buildroot}/%{_fwdefdir}/libvirtd-relocation-server
%endif

# install supportconfig plugin
mkdir -p %{buildroot}/usr/lib/supportconfig/plugins
install -m 755 %{S:4} %{buildroot}/usr/lib/supportconfig/plugins/libvirt

# install qemu hook script
install -m 755 %{S:5} %{buildroot}/%{_sysconfdir}/libvirt/hooks/qemu

%ifarch %{power64} s390x x86_64
mv %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_probes-64.stp
mv %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   %{buildroot}/%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
%endif
%fdupes -s %{buildroot}

%clean
rm -rf %{buildroot}

%check
cd tests
SKIP_TESTS=""
# These tests don't current work in a mock build root
# virnetsockettest: needs unsupported linux-user syscalls
SKIP_TESTS="$SKIP_TESTS virnetsockettest virnettlssessiontest"
# virportallocatortest fails on aarch64 due to unsupported IPV6_V6ONLY flag
%ifarch aarch64
SKIP_TESTS="$SKIP_TESTS virportallocatortest"
%endif
for i in $SKIP_TESTS
do
  rm -f $i
  printf 'int main(void) { return 0; }' > $i.c
done
make %{?_smp_mflags}

if ! make %{?_smp_mflags} check VIR_TEST_DEBUG=1
then
  cat test-suite.log || true
  exit 1
fi

%pre daemon
%{_bindir}/getent group libvirt >/dev/null || %{_sbindir}/groupadd -r libvirt
%service_add_pre libvirtd.service virtlockd.service virtlockd.socket virtlogd.service virtlogd.socket

%post daemon
/sbin/ldconfig
%if %{with_apparmor} && 0%{?suse_version} >= 1500
%apparmor_reload /etc/apparmor.d/usr.sbin.libvirtd
%endif
%if %{with_firewalld}
%firewalld_reload
%endif
%service_add_post libvirtd.service virtlockd.service virtlockd.socket virtlogd.service virtlogd.socket
%{fillup_only -n libvirtd}
%{fillup_only -n virtlockd}
%{fillup_only -n virtlogd}

%preun daemon
%service_del_preun libvirtd.service virtlockd.service virtlockd.socket virtlogd.service virtlogd.socket

%postun daemon
/sbin/ldconfig
# On upgrade, defer restarting daemons until %posttrans
if test $1 -eq 0 ; then
    for service in libvirtd virtlockd virtlogd ; do
        rm -f "/var/lib/systemd/migrated/$service" 2> /dev/null || :
    done
    /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi
   %service_del_postun libvirtd.service virtlockd.service virtlockd.socket virtlogd.service virtlogd.socket

%posttrans daemon
# All connection drivers should be installed post transaction.
# Time to restart daemons.
if test "$YAST_IS_RUNNING" != "instsys" -a "$DISABLE_RESTART_ON_UPDATE" != yes ; then
    for service in libvirtd virtlockd virtlogd ; do
        /usr/bin/systemctl try-restart ${service}.service >/dev/null 2>&1 || :
    done
fi

%post daemon-config-network
# Install the default network if one doesn't exist
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    UUID=`/usr/bin/uuidgen`
    sed -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
fi

%pre client
%service_add_pre libvirt-guests.service

%post client
%service_add_post libvirt-guests.service
%{fillup_only -n libvirt-guests}

%preun client
%service_del_preun libvirt-guests.service
if [ $1 = 0 ]; then
    rm -f /var/lib/libvirt/libvirt-guests
fi

%postun client
%service_del_postun -n libvirt-guests.service

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post nss -p /sbin/ldconfig

%postun nss -p /sbin/ldconfig

%files
%doc %{_docdir}/%{name}/libvirt.README

%files daemon
%{_sbindir}/libvirtd
%{_sbindir}/virtlogd
%{_sbindir}/virtlockd
%dir %{_libdir}/%{name}
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/hooks
%{_fillupdir}/sysconfig.libvirtd
%{_fillupdir}/sysconfig.virtlogd
%{_fillupdir}/sysconfig.virtlockd
%{_unitdir}/libvirtd.service
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_sbindir}/rclibvirtd
%{_sbindir}/rcvirtlogd
%{_sbindir}/rcvirtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%dir %{_datadir}/augeas/
%dir %{_datadir}/augeas/lenses
%dir %{_datadir}/augeas/lenses/tests
%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/vsh
%endif
%dir %{_localstatedir}/lib/libvirt/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/
%dir %attr(0755, root, root) %{_libdir}/%{name}/lock-driver
%attr(0755, root, root) %{_libdir}/%{name}/lock-driver/lockd.so
%if %{with_polkit_rules}
%{_datadir}/polkit-1/rules.d/50-libvirt.rules
%endif
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_iohelper
%doc %{_mandir}/man8/libvirtd.8*
%doc %{_mandir}/man8/virtlogd.8*
%doc %{_mandir}/man8/virtlockd.8*
%doc %{_mandir}/man7/virkey*.7*
%if %{with_apparmor}
%dir %{_sysconfdir}/apparmor.d
%dir %{_sysconfdir}/apparmor.d/abstractions
%dir %{_sysconfdir}/apparmor.d/libvirt
%dir %{_sysconfdir}/apparmor.d/local
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.sbin.libvirtd
%config(noreplace) %{_sysconfdir}/apparmor.d/usr.lib.libvirt.virt-aa-helper
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/libvirt-qemu
%config(noreplace) %{_sysconfdir}/apparmor.d/abstractions/libvirt-lxc
%config(noreplace) %{_sysconfdir}/apparmor.d/libvirt/TEMPLATE.lxc
%config(noreplace) %{_sysconfdir}/apparmor.d/libvirt/TEMPLATE.qemu
%config(noreplace) %{_sysconfdir}/apparmor.d/local/usr.lib.libvirt.virt-aa-helper
%{_libdir}/%{name}/virt-aa-helper
%endif
%if %{with_firewalld}
%dir %{_libexecdir}/firewalld
%dir %{_libexecdir}/firewalld/services
%{_libexecdir}/firewalld/services/libvirtd-relocation-server.xml
%else
%config %{_fwdefdir}/libvirtd-relocation-server
%endif
%dir /usr/lib/supportconfig
%dir /usr/lib/supportconfig/plugins
/usr/lib/supportconfig/plugins/libvirt

%files daemon-hooks
%{_sysconfdir}/libvirt/hooks/qemu

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml

%files daemon-config-nwfilter
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%config %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_leaseshelper
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%files daemon-driver-nodedev
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%files daemon-driver-secret
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so

%files daemon-driver-storage

%files daemon-driver-storage-core
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_parthelper
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%dir %{_libdir}/%{name}/storage-backend
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so

%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_qemu}

%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/lib/libvirt/qemu/
%dir %attr(0750, %{qemu_user}, %{qemu_group}) %{_localstatedir}/cache/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%endif

%if %{with_lxc}

%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_lxc
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%attr(0755, root, root) %{_bindir}/virt-lxc-convert
    %if ! 0%{?is_opensuse}
%{_bindir}/virt-create-rootfs
%doc %{_mandir}/man1/virt-create-rootfs.1*
    %endif
%endif

%if %{with_uml}

%files daemon-driver-uml
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.uml
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/uml/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/uml/
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_uml.so
%endif

%if %{with_xen}

%files daemon-driver-xen
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_xen.so
%endif

%if %{with_libxl}

%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%dir %{_libdir}/%{name}/connection-driver
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}

%files daemon-driver-vbox
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_qemu}

%files daemon-qemu
%doc %{_docdir}/%{name}/libvirt-daemon-qemu.README
%endif

%if %{with_lxc}

%files daemon-lxc
%doc %{_docdir}/%{name}/libvirt-daemon-lxc.README
%endif

%if %{with_uml}

%files daemon-uml
%doc %{_docdir}/%{name}/libvirt-daemon-uml.README
%endif

%if %{with_xen} || %{with_libxl}

%files daemon-xen
%doc %{_docdir}/%{name}/libvirt-daemon-xen.README
%endif

%if %{with_vbox}

%files daemon-vbox
%doc %{_docdir}/%{name}/libvirt-daemon-vbox.README
%endif

%files client
%doc %{_mandir}/man1/virsh.1*
%doc %{_mandir}/man1/virt-xml-validate.1*
%doc %{_mandir}/man1/virt-pki-validate.1*
%doc %{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate
%dir %{_libdir}/%{name}
%attr(0755, root, root) %{_libdir}/%{name}/libvirt-guests.sh
%{_fillupdir}/sysconfig.libvirt-guests
%{_unitdir}/libvirt-guests.service
%{_sbindir}/rclibvirt-guests

%files libs -f %{name}.lang
%doc AUTHORS ChangeLog.gz NEWS README README.md COPYING COPYING.LESSER 
%config(noreplace) %{_sysconfdir}/%{name}/libvirt.conf
%config(noreplace) %{_sysconfdir}/%{name}/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/cputypes.rng
%{_datadir}/libvirt/schemas/domaincaps.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storagecommon.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagevol.rng
%{_datadir}/libvirt/cpu_map.xml
%{_datadir}/libvirt/test-screenshot.png

%dir %{_sysconfdir}/sasl2/
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf

%files admin
%doc %{_mandir}/man1/virt-admin.1*
%{_bindir}/virt-admin

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%{_includedir}/libvirt
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc
%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml

%files doc
# Website
%dir %{_docdir}/libvirt
%doc %{_docdir}/%{name}/*.png
%doc %{_docdir}/%{name}/*.html
%doc %{_docdir}/%{name}/*.gif
%doc %{_docdir}/%{name}/*.css
%doc %{_docdir}/%{name}/html
%doc %{_docdir}/%{name}/internals
%doc %{_docdir}/%{name}/logos
%doc %{_docdir}/%{name}/fonts

# API docs
%dir %{_datadir}/gtk-doc/html/libvirt/
%doc %{_datadir}/gtk-doc/html/libvirt/*

%if %{with_sanlock}

%files lock-sanlock
%doc %{_mandir}/man8/virt-sanlock-cleanup.8*
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/%{name}/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/%{name}/libxl-sanlock.conf
    %endif
%dir %{_libdir}/%{name}/lock-driver/
%attr(0755, root, root) %{_libdir}/%{name}/lock-driver/sanlock.so
%dir %{_datadir}/augeas/
%dir %{_datadir}/augeas/lenses
%dir %{_datadir}/augeas/lenses/tests
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0700, root, root) %{_localstatedir}/lib/%{name}/sanlock
%{_sbindir}/virt-sanlock-cleanup
%attr(0755, root, root) %{_libdir}/%{name}/libvirt_sanlock_helper
%endif

%if %{with_wireshark}

%files -n wireshark-plugin-libvirt
%{_libdir}/wireshark/plugins/*/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%changelog
* Fri Jun 14 2019 James Fehlig <jfehlig@suse.com>
- api: disallow virConnectGetDomainCapabilities,
  virDomainManagedSaveDefineXML, and virDomainSaveImageGetXMLDesc
  on read-only connections
  CVE-2019-10161-api-disallow-virDomainSaveImageGetXMLDesc.patch,
  CVE-2019-10166-api-disallow-virDomainManagedSaveDefineXML.patch,
  CVE-2019-10167-api-disallow-virConnectGetDomainCapabilities.patch,
  CVE-2019-10161, CVE-2019-10166, CVE-2019-10167
  bsc#1138301, bsc#1138302, bsc#1138303
* Thu May 23 2019 Jim Fehlig <jfehlig@suse.com>
- spec: add systemd-container dependency to qemu and lxc drivers
  bsc#1136109
* Mon May 20 2019 James Fehlig <jfehlig@suse.com>
- cpu_map: add cpu feature md-clear. CVE-2018-12126,
  CVE-2018-12127, CVE-2018-12130, CVE-2019-11091
  5cd9db3a-cputest-add-data-E3-1225-v5.patch,
  538d8735-cpu_map-Define-md-clear-CPUID-bit.patch,
  4cb90fa2-4-1-maint-branch-remove-stibp-from-tests.patch
  bsc#1111331, bsc#1135273
* Fri Apr  5 2019 James Fehlig <jfehlig@suse.com>
- CVE-2019-3886: disallow virDomainGetHostname and virDomainGetTime
  for read-only connections and users
  CVE-2019-3886-api.patch, CVE-2019-3886-remote.patch
  bsc#1131595
* Fri Mar 22 2019 James Fehlig <jfehlig@suse.com>
- apparmor: reintroduce upstream lxc mount rules
  Drop apparmor-no-mount.patch
  bsc#1130129
* Fri Mar 22 2019 James Fehlig <jfehlig@suse.com>
- hook: encode incoming XML to UTF-8 before passing to lxml etree
  fromstring method
  Modifed suse-qemu-domain-hook.py
  boo#1123642
* Fri Mar 15 2019 James Fehlig <jfehlig@suse.com>
- supportconfig: collect rotated logs in /var/log/libvirt/*
  Modified libvirt-supportconfig
  bsc#1124667
* Wed Mar 13 2019 James Fehlig <jfehlig@suse.com>
- conf: add new 'xenbus' controller type
  09eb1ae0-conf-add-xenbus-controller.patch
- libxl: support Xen's max_grant_frames setting with maxGrantFrames
  attribute on the xenbus controller
  fb059757-libxl-add-xenbus-controller.patch,
  ec5a1191-libxl-support-max-grant-frames.patch,
  5a64c202-xenconfig-support-max-grant-frames.patch
  bsc#1126325
* Mon Mar 11 2019 James Fehlig <jfehlig@suse.com>
-  util: skip RDMA detection for non-PCI network devices
  f38ef0fa-no-RDMA-check.patch
  bsc#1112182
* Fri Mar  1 2019 James Fehlig <jfehlig@suse.com>
- qemu: fix potential libvirtd crash in qemuAgentGetInterfaces
  CVE-2019-3840
  7cfd1fbb-qemu-CVE-2019-3840.patch
  bsc#1127458
* Tue Feb 19 2019 James Fehlig <jfehlig@suse.com>
- qemu: don't use CAP_DAC_OVERRIDE capability if non-root
  620d9dd5-qemu-no-dac-override-nonroot.patch
  boo#1125665
* Fri Feb  8 2019 James Fehlig <jfehlig@suse.com>
- qemu: fix issues related to restricted permissions on /dev/sev
  b6440119-qemu-conf-sev.patch, a404ac34-qemu-cgroup-sev.patch,
  6fd4c8f8-qemu-domain-sev.patch, 17f6a257-security-dac-sev.patch,
  a2d3dea9-qemu-caps-dac-override-sev.patch
  bsc#1102604
* Wed Jan 23 2019 James Fehlig <jfehlig@suse.com>
- apparmor: add support for named profiles
  70c2933d-apparmor-named-profiles.patch
  boo#1118952
- libxl: save current memory value after successful balloon
  11c8aca9-libxl-set-mem-after-balloon.patch
  bsc#1120813
* Mon Nov 26 2018 James Fehlig <jfehlig@suse.com>
- apparmor: Fix ptrace rules
  8741b943-apparmor-ptrace-rules.patch
  bsc#1117058
* Tue Nov  6 2018 James Fehlig <jfehlig@suse.com>
- libxl: add support for soft reset
  14d03b27-libxl-rm-redundant-virObjectEventStateQueue.patch,
  82452a5d-libxl-rm-goto-libxlDomainShutdownThread.patch,
  da4b0fd9-libxl-support-soft-reset.patch
  bsc#1081516
* Tue Oct 16 2018 jfehlig@suse.com
- qemu: Add support for SEV guests
  d4005609-qemu-query-sev-caps.patch,
  5dca09c1-expose-sev-domcaps.patch,
  45422935-intro-virNodeGetSEVInfo-API.patch,
  e4db4daf-remote-virNodeGetSEVInfo.patch,
  6596ac42-backend-virNodeGetSEVInfo.patch,
  e5791a03-intro-launch-security.patch,
  a9caa981-add-sev-shared-dev.patch,
  11ab77fe-support-launch-sev-guest.patch,
  077c9a25-intro-virDomainGetLaunchSecurityInfo-API.patch,
  a12278a1-remote-launch-security.patch,
  bfaa61c8-backend-virDomainGetLaunchSecurityInfo.patch,
  a95b99d0-rename-reducedPhysBits.patch,
  e56ff8bc-prefer-camelCase-launchSecurity.patch,
  dfc56964-remove-virQEMUCapsSetSEVCapabilities.patch,
  2382a236-fix-qemuDomainGetSEVMeasurement-leak.patch,
  2555749f-rename-qemuBuildSevCreateFile.patch,
  6718132d-use-cleanup-qemuProcessSEVCreateFile.patch,
  6b90f4bb-rename-virDomainSevDefPtr.patch,
  6bbb35ee-rename-sev-funcs.patch,
  c92c6cd2-qemuBuildSevCommandLine.patch,
  84e4046c-fix-leak-qemuBuildSevCommandLine.patch,
  4817687a-rework-virDomainSEVDefParseXML.patch,
  a349c6c2-ignore-query-sev-capabilities-errors.patch,
  6688393c-fix-sev-element-formatting.patch,
  54c54b56-sev-use-EnterMonitor.patch,
  6d490ed0-fix-sev-endjob.patch,
  e039a830-fix-qemuProcessSEVCreateFile-retval.patch
  FATE#325817
- Fix virNodeGetSEVInfo API crashing libvirtd on AMD SEV
  enabled host
  764491c9-qemu-fix-probing-sev-support.patch,
  77f51ab5-qemu-caps-format-sev-platform-data.patch,
  cc786a8f-qemu-free-sev-caps.patch
  bsc#1108395
* Wed Sep 19 2018 James Fehlig <jfehlig@suse.com>
- libxl: fix VM migration on busy hosts
  60b4fd90-libxl-rm-vm-finish-phase.patch,
  e39c66d3-libxl-fix-p2p-migration.patch,
  47da84e0-libxl-fix-job-handling-migsrc.patch,
  0149464a-libxl-fix-job-handling-migdst.patch,
  5ea2abb3-libxl-join-mig-rcv-thread.patch
  bsc#1108086
* Fri Aug 31 2018 jfehlig@suse.com
- util: don't check for parallel iteration in hash-related
  functions
  4d7384eb-dont-check-parallel-iteration-hash-func.patch
  bsc#1106420
* Mon Aug 13 2018 jfehlig@suse.com
- spec: don't restart libvirt-guests when updating libvirt-client
  bsc#1104662
* Fri Jul  6 2018 jfehlig@suse.com
- libxl: Implement virDomainBlockResize
  0001-libxl-add-support-for-BlockResize-API.patch
  FATE#325467, bsc#1094325, bsc#1094725
* Tue Jun  5 2018 jfehlig@suse.com
- virt-aa-helper: add SUSE path to OVMF and AAVMF images
  Adjusted suse-ovmf-paths.patch
  boo#1095556
* Mon Jun  4 2018 jfehlig@suse.com
- libxl: fix leaking logfile fds
  67c56f6e-libxl-logfd-leak-fix.patch
  bsc#1094480
* Fri Jun  1 2018 jfehlig@suse.com
- spec: only use apparmor-rpm-macros when suse_version >= 1500
* Wed May 30 2018 jfehlig@suse.com
- libxl: don't set hasManagedSave when performing save
  ac4a12db-libxl-fix-hasManagedSave.patch
  bsc#959329
* Tue May 22 2018 jfehlig@suse.com
- cpu: add support for 'ssbd' and 'virt-ssbd' CPUID feature bits
  CVE-2018-3639
  1dbca2ec-CVE-2018-3639.patch, 92673422-CVE-2018-3639.patch
  bsc#1092885
* Thu Apr  5 2018 jfehlig@suse.com
- util: improvements in error handling
  09877303-virSocketAddrParseInternal.patch,
  412afdb8-intro-virSocketAddrParseAny.patch
  bsc#1080957
* Wed Mar 21 2018 jfehlig@suse.com
- libxl: don't hardcode scheduler weight
  83edaf44-libxl-dont-hardcode-sched-weight.patch
  bsc#1086377
* Tue Mar 20 2018 jfehlig@suse.com
- libxl: fixes and improvements in migration APIs
  64370c4b-libxl-MigrateBegin.patch,
  99486799-libxl-MigrateConfirm.patch,
  f5eacf2a-libxl-MigratePerform.patch,
  4e6fcdb6-libxl-libxlDomObjFromDomain-cleanup.patch,
  fe51dbda-libxl-use-FindByRef.patch,
  60b3fcd9-libxl-MigratePrepare.patch,
  3c89868c-libxl-lock-after-ListRemove.patch,
  13e81fc6-libxl-EndJob-on-error.patch,
  594b8b99-libxl-DefineXMLFlags-API-pattern.patch,
  c66e344e-libxl-dont-deref-NULL.patch
  bsc#1080957
* Wed Mar 14 2018 jfehlig@suse.com
- Install correct firewall service file depending on availability
  of firewalld vs SuSEfirewall2
  libvirtd-relocation-server.xml
  bsc#1083455
* Wed Mar 14 2018 jfehlig@suse.com
- qemu: avoid denial of service reading from QEMU guest agent
  CVE-2018-1064
  fbf31e1a-CVE-2018-1064.patch
  bsc#1083625
* Tue Mar 13 2018 jfehlig@suse.com
- virtlockd: fix loosing lock on re-exec
  464889ff-rpc-aquire-ref-dispatch.patch,
  c6f1d519-rpc-simplify-dispatch.patch,
  06e7ebb6-rpc-invoke-dispatch-unlocked.patch,
  86cae503-rpc-fix-pre-exec.patch,
  eefabb38-rpc-virtlockd-virtlogd-single-thread.patch
  bsc#1076861
* Tue Mar 13 2018 jfehlig@suse.com
- libvirtd: fix potential deadlock when reloading
  33c6eb96-fix-libvirtd-reload-deadlock.patch
  bsc#1079150
* Tue Mar 13 2018 jfehlig@suse.com
- libvirtd: Explicit dependency on systemd-machined
  1b0c42ff-libvirtd-depend-machined.patch
  bsc#1074014
* Fri Feb 23 2018 jfehlig@suse.com
- libxl: round memory values to next 1MiB increment
  ef71caea-libxl-memalign.patch
  bsc#1082041
* Wed Feb 21 2018 jfehlig@suse.com
- libxl: add support for specifying clock offset and adjustment
  c391e07e-libxl-clock-settings.patch
  bsc#1082161
* Fri Feb  9 2018 cbosdonnat@suse.com
- Remove all uses of python2 during the build (bsc#1080034)
    6b3d716e-keycodemap-py3.patch
    apibuild-py3.patch
- Determine hostname early to avoid code injection
  in lxc driver. (bsc#1080042)
    759b4d1b-virlog-determine-the-hostname-on-startup-CVE-2018-67.patch
    c2dc6698-fix-deadlock-obtaining-hostname.patch
- Add basic support of connectGetAllDomainStats for lxc driver
  (fate#323742)
    0001-Extract-stats-functions-from-the-qemu-driver.patch
    0002-lxc-implement-connectGetAllDomainStats.patch
* Fri Jan 26 2018 jfehlig@suse.com
- qemu: Support setting OEM strings in SMBIOS
  68eed56b-conf-smbios-oem-strings.patch,
  76977061-qemu-smbios-oem-strings.patch
  FATE#323624
- libxl: resume lock process after failed migration
  0c710a37-libxl-resume-lock-on-mig-failure.patch
  bsc#1076861
* Thu Jan 25 2018 jfehlig@suse.com
- qemu hook: Change shebang to /usr/bin/python3
- spec: Require python lxml in daemon-hooks subpackage
* Fri Jan 19 2018 jfehlig@suse.com
- Update to libvirt 4.0.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    2d07f1f0-fix-storage-crash.patch,
    69ed99c7-dom0-persistent.patch,
    8599aedd-libvirt-guests-dom0-filter.patch,
    0f33025a-virt-aa-helper-handle-more-disk-images.patch,
    b475a91b-add-virStringFilterChars-string-utility.patch,
    faec1958-lxc-set-hostname-based-on-container-name.patch,
    2089ab21-netserver-close-clients-before-stopping-all-drivers.patch,
    fix-virt-aa-helper-profile.patch,
  - Patches added to fix upstream bugs:
    72adaf2f-revert-qemu-monitor-error-report.patch,
    71d56a39-nodedev-fix-parse-PCI-address.patch
  - CVE-2018-5748, CVE-2017-5715, bsc#1071651, bsc#1076500
* Thu Jan 11 2018 jfehlig@suse.com
- Add a qemu hook script providing functionality similar to Xen's
  block-dmmd script
  suse-qemu-domain-hook.py
  FATE#324177
* Wed Jan  3 2018 cbosdonnat@suse.com
- Fix apparmor rules for virt-aa-helper (bsc#1074265)
  fix-virt-aa-helper-profile.patch
- Lift VirtualBox dependency version to include 5.2.x
- Update upstreamed patches
  Removed patches:
  * daemon-close-crasher.patch
  * lxc-hostname.patch
  Added patches:
  * 2089ab21-netserver-close-clients-before-stopping-all-drivers.patch
  * b475a91b-add-virStringFilterChars-string-utility.patch
  * faec1958-lxc-set-hostname-based-on-container-name.patch
* Wed Dec 20 2017 cbosdonnat@suse.com
- Close clients before drivers are cleaned up to avoid crash at
  libvirtd stop (bsc#1073730)
  daemon-close-crasher.patch
- Set a hostname on lxc containers based on guest's name.
  lxc-hostname.patch
- Enhance apparmor rules for virt-aa-helper (bsc#1070916)
  0f33025a-virt-aa-helper-handle-more-disk-images.patch
* Mon Dec 18 2017 jfehlig@suse.com
- libvirt-guests: fix 'stop' operation when action is 'suspend'
  69ed99c7-dom0-persistent.patch,
  8599aedd-libvirt-guests-dom0-filter.patch
  bsc#1070130
* Thu Dec 14 2017 jfehlig@suse.com
- storage: Don't dereference driver object if virStorageSource is
  not initialized
  2d07f1f0-fix-storage-crash.patch
  bsc#1072974
* Mon Dec  4 2017 jfehlig@suse.com
- Update to libvirt 3.10.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - bsc#1070285, bsc#1070478, boo#1070914,
  - FATE#323473, FATE#324365, FATE#324479
* Fri Dec  1 2017 jfehlig@suse.com
- Update to libvirt 3.10.0 RC2
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    8056721c-qemu-null-storage-source.patch,
    74a13be4-xdr-flags.patch,
    apparmor-rules-for-new-mediation-features.patch,
    apparmor-fine-grained-mount-rules.patch
  - bsc#1070285, bsc#1070478, FATE#323473, FATE#324479
* Thu Nov 30 2017 jfehlig@suse.com
- spec: remove use of 'systemctl enable'
  bsc#1038401
* Thu Nov 30 2017 jfehlig@suse.com
- spec: enable firewalld support for SLE15, Leap15, and Tumbleweed
  FATE#320794
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Wed Nov 22 2017 kukuk@suse.de
- spec: Add BuildRequires for libtirpc-devel in preparation of
  removal of sunrpc from glibc
- build: Use XDR_CFLAGS in more places
  74a13be4-xdr-flags.patch
* Wed Nov 22 2017 olaf@aepfle.de
- Replace hardcoded libvirt with Name tag when refering to subpkgs
- Remove dependencies to /bin/sh in libs and nss %%post scripts
* Fri Nov 17 2017 jfehlig@suse.com
- apparmor: allow libvirtd to send signals to unconfined processes
  suse-apparmor-signal.patch
  boo#1065123
* Fri Nov 17 2017 jfehlig@suse.com
- qemu: Tolerate storage source private data being NULL
  8056721c-qemu-null-storage-source.patch
  bsc#1068752
* Wed Nov  8 2017 jfehlig@suse.com
- apparmor: add rules for new mediation features
  apparmor-rules-for-new-mediation-features.patch,
  apparmor-fine-grained-mount-rules.patch
  bsc#1066124, boo#1065123
- spec: unconditionally enable the wireshark dissector
* Wed Nov  8 2017 cbosdonnat@suse.com
- Replace %%{with_sle_build} by ! 0%%{?is_opensuse}
  bsc#940315
* Thu Nov  2 2017 jfehlig@suse.com
- Update to libvirt 3.9.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    c44b29aa-apparmor-dnsmasq-ptrace.patch,
    441d3eb6-qemu-tls-client-verify-server-cert.patch
* Mon Oct 16 2017 jfehlig@suse.com
- qemu: ensure TLS clients always verify the server certificate
  CVE-2017-1000256
  441d3eb6-qemu-tls-client-verify-server-cert.patch
  bsc#1062563
* Thu Oct 12 2017 jengelh@inai.de
- Do not ignore errors from useradd/groupadd.
- Invoke/expand %%service_* just once per scriptlet.
- Replace some old macros.
* Tue Oct 10 2017 jfehlig@suse.com
- spec: libvirt-daemon-qemu requires libvirt-daemon-driver-storage
  bsc#1062620
* Mon Oct  9 2017 jfehlig@suse.com
- spec: reload libvirtd Apparmor profile in %%post
  bsc#1060860
* Fri Oct  6 2017 jfehlig@suse.com
- apparmor: add dnsmasq ptrace rule to libvirtd profile
  c44b29aa-apparmor-dnsmasq-ptrace.patch
  bsc#1060860
* Thu Oct  5 2017 jfehlig@suse.com
- spec: Add dependency to UEFI firmwares since paths are specified
  at build time
* Wed Oct  4 2017 jfehlig@suse.com
- Update to libvirt 3.8.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    92bd87a2-ryzen-test-data.patch,
    5c83b360-epyc-test-data.patch,
    a0b62843-epyc-cpu-model.patch,
    f305d8a1-apparmor-attach_disconnected.patch,
    b482925c-apparmor-ptrace-support.patch
* Tue Oct  3 2017 jfehlig@suse.com
- Enable firewalld support for openSUSE >= 42.2
* Tue Sep 26 2017 jfehlig@suse.com
- apparmor: Add rules for kernel 4.13 ptrace checks
  b482925c-apparmor-ptrace-support.patch
  Drop temporary workaround apparmor-ptrace-support.patch
  bsc#1058847
- apparmor: Add rules for denial encountered when starting
  confined domains
  f305d8a1-apparmor-attach_disconnected.patch,
  suse-apparmor-libnl-paths.patch
  Drop old, useless, undocumented apparmor-fixes.patch
* Wed Sep 20 2017 jfehlig@suse.com
- apparmor: add temporary profile fixes to allow starting domains
  apparmor-ptrace-support.patch
  bsc#1058847
* Fri Sep 15 2017 jfehlig@suse.com
- cpu: Add new EPYC CPU model
  92bd87a2-ryzen-test-data.patch, 5c83b360-epyc-test-data.patch,
  a0b62843-epyc-cpu-model.patch
  bsc#1052825
* Fri Sep 15 2017 jfehlig@suse.com
- Update to libvirt 3.7.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    8982f3ab-util-hash-header.patch,
    0b1ecf7b-virHashCodeGen-mockable.patch,
    f536b0dd-tests-arch-independent-hash.patch,
    e4cb8500-avoid-malicious-ssh-hostname-as-args.patch
* Fri Sep  1 2017 jfehlig@suse.com
- Support OVMF 4MB firmware images
  Adjustment to spec file and suse-ovmf-paths.patch
* Thu Aug 31 2017 jfehlig@suse.com
- supportconfig plugin: list active networks, interfaces and
  storage pools
* Tue Aug 29 2017 jfehlig@suse.com
- rpc: avoid ssh interpreting malicious hostname as arguments
  e4cb8500-avoid-malicious-ssh-hostname-as-args.patch
  bsc#1053600
* Thu Aug  3 2017 jfehlig@suse.com
- Update to libvirt 3.6.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
- Fix unit tests on s390x and ppc64
  8982f3ab-util-hash-header.patch,
  0b1ecf7b-virHashCodeGen-mockable.patch.
  f536b0dd-tests-arch-independent-hash.patch
- Patch cleanup
  - Renamed libvirtd-defaults.patch to
    suse-libvirtd-disable-tls.patch
  - Renamed libvirtd-init-script.patch to
    suse-libvirtd-sysconfig-settings.patch
  - Renamed virtlockd-init-script.patch to
    suse-virtlockd-sysconfig-settings.patch
  - Renamed virtlogd-init-script.patch to
    suse-virtlogd-sysconfig-settings.patch
  - Renamed libvirt-guests-init-script.patch to
    suse-libvirt-guests-service.patch
  - Combined suse-libvirtd-service.patch and
    systemd-service-xen.patch to suse-libvirtd-service-xen.patch
    since both patches add Xen support to libvirtd service file
  - Pull OVMF-related changes from suse-qemu-conf.patch into a
    new suse-ovmf-paths.patch
* Wed Jul 26 2017 jfehlig@suse.com
- Add a supportconfig plugin
  libvirt-supportconfig
  FATE#323661
* Wed Jul 26 2017 jfehlig@suse.com
- Remove Requires on bridge-utils
  FATE#323639
* Fri Jul 21 2017 dmueller@suse.com
- drop dependency on xen for armv6hl (not supported and does not
  build)
* Wed Jul  5 2017 jfehlig@suse.com
- Update to libvirt 3.5.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    5004f121-virFdStreamThread-dont-exceed-length.patch,
    1a4b21f1-set-EOF-on-end-of-stream.patch
* Thu Jun 29 2017 jengelh@inai.de
- Remove --with-pic which is only for static libs
- Use %%_smp_mflags instead of just %%jobs
* Wed Jun  7 2017 jfehlig@suse.com
- misc spec file cleanup
  - remove checks for old distros well beyond EOL
  - enable wireshark dissector for Leap >= 42.2 and Factory
  - remove support for old, non-systemd distros
  - replace $RPM_ shell vars with modern macros
* Tue Jun  6 2017 jfehlig@suse.com
- Don't exceed specified length when reading from stream
  5004f121-virFdStreamThread-dont-exceed-length.patch,
  1a4b21f1-set-EOF-on-end-of-stream.patch
* Fri Jun  2 2017 jfehlig@suse.com
-  Update to libvirt 3.4.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    aeda1b8c-qemu-no-error-shutdown.patch,
    8023b21a-conf-ioapic.patch, 6b5c6314-qemu-irqchip.patch,
    2020e2c6-conf-intremap.patch, 04028a9d-qemu-intremap.patch,
    d12781b4-conf-iommu-cache-mode-attr.patch,
    a5691448-qemu-iommu-cache-mode.patch,
    3a276c65-conf-iommu-def-stability-check.patch,
    935d927a-conf-iommu-ABI-stability-check.patch,
    4cd3f241-fix-NULL-disk-source.patch,
    975ea20f-loopback-macro.patch,
    dbb85e0c-libxl-graphics-listen-addr.patch,
    libxl-def-usbctrl.patch, revert-2841e675-mtu.patch
  - FATE#321335, bsc#1031056, bsc#1037774, bsc#1040207, bsc#1040213
* Mon May 22 2017 jfehlig@suse.com
- libxl: add default listen address for VNC and spice
  975ea20f-loopback-macro.patch,
  dbb85e0c-libxl-graphics-listen-addr.patch
  bsc#1040207
- xenconfig: fix handling of NULL disk source
  4cd3f241-fix-NULL-disk-source.patch
  bsc#1040213
* Mon May 15 2017 jfehlig@suse.com
- qemu: add support for 288 VCPUS
  aeda1b8c-qemu-no-error-shutdown.patch,
  8023b21a-conf-ioapic.patch,
  6b5c6314-qemu-irqchip.patch,
  2020e2c6-conf-intremap.patch,
  04028a9d-qemu-intremap.patch,
  d12781b4-conf-iommu-cache-mode-attr.patch,
  a5691448-qemu-iommu-cache-mode.patch,
  3a276c65-conf-iommu-def-stability-check.patch,
  935d927a-conf-iommu-ABI-stability-check.patch
  FATE#321335
- revert commit 2841e675: qemu: propagate bridge MTU into qemu
  "host_mtu"
  revert-2841e675-mtu.patch
  bsc#1037774
* Mon May  8 2017 jfehlig@suse.com
-  Update to libvirt 3.3.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Bug fixes:
    bsc#978121, bsc#1017017, bsc#1032863, bsc#1033117, bsc#1034024,
    bsc#1034146, bsc#1035995
- libxl: updated libxl-def-usbctrl.patch
  bsc#1031056
* Fri Apr 28 2017 jfehlig@suse.com
- Update to libvirt 3.3.0 RC1
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    ae102b5d7-qemu-fix-regression-when-hyperv-vendor_id-feature-is-used.patch
  - Bug fixes:
    bsc#978121, bsc#1017017, bsc#1032863, bsc#1033117, bsc#1034024,
    bsc#1034146
- libxl: add default controllers for USB devices
  libxl-def-usbctrl.patch
  bsc#1031056
* Wed Apr 12 2017 petracvv@opensuse.org
- qemu: Fix regression when hyperv/vendor_id feature is used
  Added patch:
  ae102b5d7-qemu-fix-regression-when-hyperv-vendor_id-feature-is-used.patch
  boo#1033893
* Mon Apr  3 2017 jfehlig@suse.com
- Update to libvirt 3.2.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    67dcb797-virTimeBackOffWait-sleepcap.patch,
    85af0b80-qemu-adaptive-montimeout.patch,
    d68cb4f55-extract-the-request-sending-code-from-virNetlin.patch,
    754515b7d-add-virNetlinkDumpCommand.patch,
    3ee35d7d6-more-uses-of-SYSCTL_PATH.patch,
    5dd607059-add-virNetDevGetName.patch,
    00d28a78b-check-accept_ra-before-enabling-ipv6-forward.patch
- Add Conflicts=xendomains.service to libvirtd service
  suse-libvirtd-service.patch
  bsc#1015348
* Thu Mar 23 2017 jengelh@inai.de
- RPM group fix
* Wed Mar 22 2017 cbosdonnat@suse.com
- Fail to start network instead of losing routes if IPv6 forwarding
  is required. bsc#1025252
  Added patches:
    00d28a78b-check-accept_ra-before-enabling-ipv6-forward.patch
    3ee35d7d6-more-uses-of-SYSCTL_PATH.patch
    5dd607059-add-virNetDevGetName.patch
    754515b7d-add-virNetlinkDumpCommand.patch
    d68cb4f55-extract-the-request-sending-code-from-virNetlin.patch
* Thu Mar 16 2017 jfehlig@suse.com
- qemu: Fix monitor timeout with large memory VMs
  67dcb797-virTimeBackOffWait-sleepcap.patch
  85af0b80-qemu-adaptive-montimeout.patch
  bsc#1013113
* Tue Mar  7 2017 mwilck@suse.com
- network: don't use dhcp-authoritative on static networks
  bsc#1015588
  * added network-don-t-use-dhcp-authoritative-on-static-netwo.patch
* Fri Mar  3 2017 jfehlig@suse.com
- Update to libvirt 3.1.0
  - Modularize storage driver by splitting it into backend-specific
    subpackages
  - CVE-2017-2635, bsc#1027075
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    b018ada3-shunloadtest-build-fix.patch,
    f86a7a83-libxl-dom0-balloon-fix.patch,
    6e4759d0-libxl-timer-fix.patch,
    87df87e0-libxl-timer-tsc-emulate.patch,
    b4386fda-xenconfig-timer-fix.patch,
    d3970925-timer-tests.patch,
    321a28c6-libxl-default-disk-format.patch,
    bd116810-libxl-fix-disk-detach.patch,
    ff225538-libxl-autoballoon-setting.patch,
    c89a6e78-libxl-physinfo-cleanup.patch,
    d2b77608-libxl-maxmem-fix.patch,
    79692c38-libxl-dom0-maxmem.patch,
    4ab0c959-libxl-mem-leak.patch,
    2dc1cf19-libxl-double-free.patch,
    apparmor-errormsg-fix.patch,
    apparmor-alt-seclabel.patch,
    qemu-disable-namespaces.patch
* Thu Mar  2 2017 jengelh@inai.de
- Drop author list from description. Fix summary to be more
  accurate as to what the subpackage pertains to.
* Sat Feb 18 2017 kukuk@suse.de
- Don't call insserv if we use systemd and don't require it.
* Thu Feb 16 2017 jfehlig@suse.com
- libxl: more fixes for dom0 maxmem setting
  4ab0c959-libxl-mem-leak.patch, 2dc1cf19-libxl-double-free.patch
  bsc#1017762
* Fri Feb 10 2017 jfehlig@suse.com
- apparmor: don't fail on non-apparmor <seclabel>
  apparmor-errormsg-fix.patch, apparmor-alt-seclabel.patch
  bsc#1023436
* Fri Feb 10 2017 jfehlig@suse.com
- libxl: fix reporting of domain maximum memory
  ff225538-libxl-autoballoon-setting.patch,
  c89a6e78-libxl-physinfo-cleanup.patch,
  d2b77608-libxl-maxmem-fix.patch,
  79692c38-libxl-dom0-maxmem.patch
  bsc#1017762
* Fri Feb 10 2017 jfehlig@suse.com
- libxl: set disk format to raw if not specified and fix disk
  detach
  321a28c6-libxl-default-disk-format.patch,
  bd116810-libxl-fix-disk-detach.patch
  bsc#1003379
* Thu Feb  9 2017 jfehlig@suse.com
- libxl: fix timer configurations
  6e4759d0-libxl-timer-fix.patch,
  87df87e0-libxl-timer-tsc-emulate.patch,
  b4386fda-xenconfig-timer-fix.patch, d3970925-timer-tests.patch
  bsc#1019969
* Thu Feb  2 2017 jfehlig@suse.com
- SLE12 SP2 bugs merged via version updates of the Factory libvirt
  package:
  bsc#986718
- SLE12 SP2 FATEs merged via version updates of the Factory libvirt
  package:
  FATE#316228, FATE#316628, FATE#319531, FATE#319810, FATE#320490
- Replaced libxl-dom0-balloon-fix.patch with upstream patch
  f86a7a83-libxl-dom0-balloon-fix.patch
* Fri Jan 27 2017 jfehlig@suse.com
- Fix dom0 ballooning with Xen >= 4.8
  libxl-dom0-balloon-fix.patch
  bsc#1020755
* Fri Jan 27 2017 jfehlig@suse.com
- SLE12 SP2 bugs merged via version updates of the Factory libvirt
  package:
  bsc#996020, bsc#987002, bsc#997278, bsc#998005, bsc#998389,
  bsc#1001446, bsc#1001698, bsc#1005288, bsc#1013991, bsc#1016253,
  bsc#1017086, bsc#1017762, bsc#1018189
* Fri Jan 27 2017 jfehlig@suse.com
- virt-create-rootfs is a temporary SLE-only hack that was never
  added to the Factory libvirt package, causing it to be dropped
  when rebasing SLE on Factory. Add it now but only apply
  associated patch when building for SLE.
  virt-create-rootfs.patch
  bsc#995981
* Wed Jan 18 2017 jfehlig@suse.com
- Update to libvirt 3.0.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Add b018ada3-shunloadtest-build-fix.patch to fix 'make check'
    failures
  - Add qemu-disable-namespaces.patch to temporarily disable
    qemu namespace feature until all issues are resolved
* Wed Dec 28 2016 matwey.kornilov@gmail.com
- In order to avoid issues like bsc#1017189, explicitly specify
  supported VirtualBox versions
* Mon Dec  5 2016 jfehlig@suse.com
- Update to libvirt 2.5.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
- Import new public signing key
* Wed Nov 16 2016 jfehlig@suse.com
- spec: explicitly set qemu-bridge-helper path to /usr/lib/
  bsc#999070
* Tue Nov  8 2016 cbosdonnat@suse.com
- Package org.libvirt.api.policy polkit file (bsc#959297)
- Fix postun systemd services cleanup
- Mark /etc/libvirt/nwfilter/*.xml files as config files
* Wed Nov  2 2016 jfehlig@suse.com
- Update to libvirt 2.4.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Wed Oct  5 2016 jfehlig@suse.com
- Update to libvirt 2.3.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    pci-use-driver-override-sysfs.patch,
    virHostdevFindUSBDevice-privsyms.patch, libxl-usb-vendor.patch,
    apparmor-qemu-bridge-helper.patch
* Fri Sep  2 2016 jfehlig@suse.com
- Update to libvirt 2.2.0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    856965b3-qemu-secdriver.patch,
    541e9ae6-cpu-vendor-crash-fix.patch,
    d53d4650-qemu-rbd-auth.patch
* Sat Aug 20 2016 jfehlig@suse.com
- libxl: allow vendor/product addressing for USB hostdevs
  virHostdevFindUSBDevice-privsyms.patch, libxl-usb-vendor.patch
  bsc#989646
- qemu: fix auth for rbd network disks
  d53d4650-qemu-rbd-auth.patch
  bsc#988998
- Replace cpumodel-vendor-crash-fix.patch with upstream variant
  541e9ae6-cpu-vendor-crash-fix.patch
  bsc#992425
* Fri Aug 12 2016 jfehlig@suse.com
- Update to libvirt 2.1.0
  - New subpackages libvirt-libs and libvirt-admin
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    c8f08e48-systemd-notify-fix.patch
- qemu: fix qemu.conf security_driver regression in 2.1.0 release
  856965b3-qemu-secdriver.patch
* Fri Aug  5 2016 jfehlig@suse.com
- cpu_x86: fix libvirtd segfault when host cpu is 'qemu64'
  cpumodel-vendor-crash-fix.patch
  bsc#992425
* Fri Aug  5 2016 cbosdonnat@suse.com
- bsc#988279. Move the qemu-bridge-helper apparmor profile from the
  qemu abstraction to the usr.sbin.libvirtd profile.
  apparmor-qemu-bridge-helper.patch
* Wed Aug  3 2016 jfehlig@suse.com
- spec: minor improvements to logic enabling numactl and numad
  support and fix nested if indentation
  FATE#319979
* Tue Aug  2 2016 jfehlig@suse.com
- Update patches providing support for driver_override sysfs
  interface with latest upstream variant. Dropped
  pci-simplify-stub.patch and updated
  pci-use-driver-override-sysfs.patch
  bsc#986718
* Sat Jul 30 2016 jfehlig@suse.com
- spec: enable numactl and numad support for aarch64
  FATE#319979, bsc#991377
* Fri Jul 15 2016 jfehlig@suse.com
- BuildRequires: use librbd-devel instead of ceph-devel
- Enable rbd support for aarch64
  bsc#979473
* Thu Jul 14 2016 jfehlig@suse.com
- Use driver_override sysfs interface for binding/unbinding
  PCI stub drivers
  pci-simplify-stub.patch, pci-use-driver-override-sysfs.patch
  bsc#986718
* Tue Jul 12 2016 jfehlig@suse.com
- systemd: fix ready notification on abstract socket
  c8f08e48-systemd-notify-fix.patch
  boo#987668
* Fri Jul  1 2016 jfehlig@suse.com
- Update to libvirt 2.0.0
  - Change version scheme to match libvirt's time-driven release
    schedule. <major> will be incremented on first release of
    new calendar year, <minor> on each monthly release, and
    <micro> on stable branch maintenance release
  - Include libvirt-admin utility and API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    apparmor-dont-scrub-environment-of-virtlogd-process.patch,
    e33cd67a-xenconfig-backendtype-fix.patch
* Mon Jun 20 2016 jfehlig@suse.com
- spec: Recent simplification allows using a common spec file for
  SLE and openSUSE
- Add SLE patches missing in openSUSE
  libxl-dom-reset.patch, libxl-set-migration-constraints.patch,
  libxl-set-cach-mode.patch
* Thu Jun 16 2016 jfehlig@suse.com
- xenconfig: fix conversion of <driver> to backendtype
  e33cd67a-xenconfig-backendtype-fix.patch
  bsc#984798
* Wed Jun 15 2016 jfehlig@suse.com
- Advertise aarch64 UEFI firmware paths
  - adjust spec file to include aarch64 paths in
    '--with-loader-nvram=' configure option
  - adjust qemu.conf 'nvram' option to include the SUSE paths
  bsc#981836, bsc#983747
* Thu Jun  9 2016 jfehlig@suse.com
- apparmor: Don't scrub environment of virtlogd process
  apparmor-dont-scrub-environment-of-virtlogd-process.patch
  boo#980441
* Mon Jun  6 2016 jfehlig@suse.com
- Update to libvirt 1.3.5
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    e4d131b8-mv-virDomainDefPostParseInternal.patch,
    3e428670-post-parse-implicit-video.patch,
    538012c8-default-vram.patch, 96b21fb0-vram-tests.patch,
    400e716d-libxl-noprope-emulator.patch,
    b90c4b5f-tests-use-qemu-xen.patch,
    fccf2725-libxl-API-4.4.patch,
    5325123d-libxl-migv2-save-restore.patch,
    f9edcfa4-libxl-migv2-migration.patch,
    a1c9a81a-libxl-rbd-fix.patch,
    ba566428-libxl-dom-iface-addrs.patch
- spec: simplify and cleanup by removing many conditionals that
  are never toogled. Also drop conditionals for suse_version <
  1310
* Fri May 27 2016 jengelh@inai.de
- Avoid suppressing errors during useradd/groupadd
* Wed May 25 2016 jfehlig@suse.com
-  libxl: add domainInterfaceAddresses API
  ba566428-libxl-dom-iface-addrs.patch
  bsc#979425
* Wed May 25 2016 jfehlig@suse.com
- libxl: default to qemu driver for network disks
  a1c9a81a-libxl-rbd-fix.patch
  boo#981094
* Wed May 18 2016 jfehlig@suse.com
- spec: Remove %%defattr usage
  Inspired by upstream commit 90f9193c
* Fri May 13 2016 jfehlig@suse.com
- libxl: support Xen migration stream V2
  fccf2725-libxl-API-4.4.patch,
  5325123d-libxl-migv2-save-restore.patch,
  f9edcfa4-libxl-migv2-migration.patch
  bsc#978361
* Fri May 13 2016 jfehlig@suse.com
- Fix default video RAM setting
  e4d131b8-mv-virDomainDefPostParseInternal.patch,
  3e428670-post-parse-implicit-video.patch,
  538012c8-default-vram.patch, 96b21fb0-vram-tests.patch,
  400e716d-libxl-noprope-emulator.patch,
  b90c4b5f-tests-use-qemu-xen.patch
  bsc#979397
* Fri May  6 2016 olaf@aepfle.de
- Remove unknown locales to fix build in old dists
* Tue May  3 2016 jfehlig@suse.com
- Update to libvirt 1.3.4
  - Add support for migration data compression in QEMU driver
  - Drop libvirtd.socket
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches: 216650f1-libxl-build-fix.patch,
    6d8b6d28-mark-implicit-video-primary.patch,
    03e8d5fb-qemu-perf-memory-corruption.patch,
    libvirtd-systemd-socket.patch
* Mon Apr 18 2016 jfehlig@suse.com
- qemu: perf: Fix crash/memory corruption on failed VM start
  03e8d5fb-qemu-perf-memory-corruption.patch
  bsc#977131
* Mon Apr 18 2016 jfehlig@suse.com
- Fix setting implicit video devices as primary
  6d8b6d28-mark-implicit-video-primary.patch
  bsc#977150
* Tue Apr 12 2016 jfehlig@suse.com
- Update to libvirt 1.3.3
  - perf events
  - post-copy migration support
  - NSS module
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Add rpmlintrc file to filter shlib-policy-name-error for
    new libnss_libvirt plugin
- Fix build with Xen4.7
  216650f1-libxl-build-fix.patch
* Fri Mar 18 2016 jfehlig@suse.com
- spec: restart daemons in %%posttrans after connection drivers
  have been processed
  bsc#854343, bsc#968483
* Thu Mar  3 2016 jfehlig@suse.com
- libxl: advertise system qemu instead of qemu-xen in caps
  libxl-qemu-emulator-caps.patch
  FATE#320638
* Tue Mar  1 2016 jfehlig@suse.com
- Update to libvirt 1.3.2
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Thu Feb 18 2016 jfehlig@suse.com
- libxl: Add support for block-{dmmd,drbd,npiv} scripts
  libxl-support-block-script.patch
  bsc#954872
* Sat Jan 23 2016 jfehlig@suse.com
- qemu: set /usr/share/qemu/ovmf-x86_64-ms-{code,vars}.bin as
  default UEFI firmwares for x86_64
  bsc#961853
* Mon Jan 18 2016 jfehlig@suse.com
- Update to libvirt 1.3.1
  - CVE-2015-5313
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches: 034e47c3-CVE-2015-5313.patch,
    ace1ee22-qemuxml2argv-test.patch, add-with-login-shell.patch,
    virt-aa-helper-rw-mounts.patch
* Tue Dec 22 2015 jfehlig@suse.com
- spec: perform one-time enable and start of virtlogd.socket when
  upgrading from libvirt < 1.3.0. Inspired by upstream libvirt.git
  commit da054f35.
* Fri Dec 18 2015 jfehlig@suse.com
- CVE-2015-5313: don't allow '/' in filesystem volume names
  034e47c3-CVE-2015-5313.patch
  bsc#953110
- Fix failing qemuxml2argv test on 32-bit platforms
  ace1ee22-qemuxml2argv-test.patch
* Thu Dec 17 2015 jfehlig@suse.com
- Update to libvirt 1.3.0
  - New virtlogd log daemon
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patch: 703ec1b7-qemu-bridge-helper-fix.patch
  - Added patch: virtlogd-init-script.patch
* Thu Dec  3 2015 cbosdonnat@suse.com
- Run udevadm settle after removing NICs in lxc driver.
  bsc#829033. lxc-wait-after-eth-del.patch
* Tue Nov 17 2015 cbosdonnat@suse.com
- Don't add apparmor deny rw rule for 9P readonly mounts.
  bsc#952849. virt-aa-helper-rw-mounts.patch
* Mon Nov  9 2015 cbosdonnat@suse.com
- Don't package virt-login-shell anymore as shipping it as
  non-setuid doesn't make sense. bsc#837609
  add-with-login-shell.patch
* Wed Nov  4 2015 normand@linux.vnet.ibm.com
- Detect path of qemu-bridge-helper during %%configure
  - add qemu-tools as BuildRequires for suse_version > 1130
  - add upstream patch 703ec1b7-qemu-bridge-helper-fix.patch
* Wed Nov  4 2015 jfehlig@suse.com
- Update to libvirt 1.2.21
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped patches:
    disable-virCgroupGetPercpuStats-test.patch
* Mon Nov  2 2015 jfehlig@suse.com
- spec: some minor wireshark fixups. Essentially a backport of
  commit 7c8250d7.
* Fri Oct 16 2015 cbosdonnat@suse.com
- spec: remove all dependencies on apparmor to keep it optional.
  bsc#949793
* Tue Oct 13 2015 jfehlig@suse.com
- xenconfig: set disk type to BLOCK when driver is not tap or file
  xen-sxpr-disk-type.patch
  bsc#938228
* Fri Oct  9 2015 jfehlig@suse.com
- spec: the libvirt apparmor profiles #include files from the
  apparmor-profiles package, thus should have a dependency on it
  bsc#949793
* Wed Oct  7 2015 olaf@aepfle.de
- Remove Wants=xencommons.service from libvirtd.service
  xencommons is already enabled by a global preset, and the
  absence of xen-tools.rpm causes a systemd warning
* Fri Oct  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.20
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    3468542f-virFileUnlink.patch,
    8b1d84e6-refreshVol-failure.patch,
    e0025d29-storage-mode-check.patch,
    ba25c214-libxl-log-level.patch,
    56945e13-libxl-AttachDeviceConfig-hostdev.patch
* Thu Sep 17 2015 cyliu@suse.com
- bsc#945962: SLES12 SP1 Beta3 - Pass-through NIC device via virsh
  not available to VM.
  56945e13-libxl-AttachDeviceConfig-hostdev.patch
* Tue Sep 15 2015 jfehlig@suse.com
- libxl: set driver log level to the log_level specified in
  libvirtd.conf
  ba25c214-libxl-log-level.patch
  bsc#945796
* Mon Sep 14 2015 cbosdonnat@suse.com
- CVE-2015-5247 - denial of service through root-squash NFS storage
  bsc#945645
  3468542f-virFileUnlink.patch
  8b1d84e6-refreshVol-failure.patch
  e0025d29-storage-mode-check.patch
* Wed Sep  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.19
  - Improved ppc64 support
  - New virDomainRename API
  - Support for PCI Express controllers in QEMU
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    269d39af-storage-allocation-fix.patch,
    26c5fa3a-virt-aa-helper-missing-doc.patch,
    d25a5e08-virt-aa-helper-simplify-restriction-logic.patch,
    2f01cfdf-virt-aa-helper-allow-ovmf.patch,
    91fdcefa-virt-aa-helper-allow-nvram.patch,
    52970dec-virt-aa-helper-improve-valid-path.patch,
    44a54eb0-libxl-fix-refcnt-MigrationDstArgs.patch,
    15120b8c-libxl-no-resume-on-suspend-fail.patch,
    e80b84a7-libxl-acquire-job-on-migrate.patch,
    60acb38-revert-curmem-inactive-dom.patch
* Fri Aug 28 2015 jfehlig@suse.com
- Replace local libxl patches with upstream variants
  Dropped:
  0003-libxl-fix-ref-counting-of-libxlMigrationDstArgs.patch
  0004-libxl-don-t-attempt-to-resume-domain-when-suspend-fa.patch
  0005-libxl-acquire-a-job-when-receiving-a-migrating-domai.patch
  Added:
  44a54eb0-libxl-fix-refcnt-MigrationDstArgs.patch
  15120b8c-libxl-no-resume-on-suspend-fail.patch
  e80b84a7-libxl-acquire-job-on-migrate.patch
  bsc#936185
- Added another virt-aa-helper upstream patch
  52970dec-virt-aa-helper-improve-valid-path.patch
  lp#1483071
- Added upstream patch to fix libvirt-tck memory balloon test
  failure on Xen
  60acb38-revert-curmem-inactive-dom.patch
* Wed Aug 26 2015 cbosdonnat@suse.com
- Fix generated apparmor profile to allow access to ovmf and nvram.
  26c5fa3a-virt-aa-helper-missing-doc.patch
  2f01cfdf-virt-aa-helper-allow-ovmf.patch
  91fdcefa-virt-aa-helper-allow-nvram.patch
  d25a5e08-virt-aa-helper-simplify-restriction-logic.patch
  lp#1483071
* Mon Aug 24 2015 jfehlig@suse.com
- storage: only run safezero if allocation is > 0
  269d39af-storage-allocation-fix.patch
  bsc#942085
* Mon Aug  3 2015 jfehlig@suse.com
- Update to libvirt 1.2.18
  - libxl: support dom0
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches:
    e44bcae-virt-aa-helper-trailing-slash.patch,
    a55a5e7-virt-aa-helper-log.patch,
    61dab0f-virt-aa-helper-renaming.patch,
    24f3c2f-virt-aa-helper-fix-caps.patch,
    45697fe5-libxl-support-dom0.patch,
    e9c27344-libxl-fix-virDomainObj-state.patch,
    4ffb21c8-libxl-dom0-state-fix.patch,
    qemu-nbd-cleanup-fix.patch
* Fri Jul 31 2015 jfehlig@suse.com
- Fix crash in libxl driver on receiving side
  0003-libxl-fix-ref-counting-of-libxlMigrationDstArgs.patch
  0004-libxl-don-t-attempt-to-resume-domain-when-suspend-fa.patch
  0005-libxl-acquire-a-job-when-receiving-a-migrating-domai.patch
  bsc#936185
* Fri Jul 10 2015 jfehlig@suse.com
- libxl: set dom0 state to running
  4ffb21c8-libxl-dom0-state-fix.patch
  bsc#937316
- libxl: support management of dom0
  45697fe5-libxl-support-dom0.patch
  bsc#937316
- libxl: libxl: fix setting state of virDomainObj
  e9c27344-libxl-fix-virDomainObj-state.patch
  bsc#934937
* Fri Jul 10 2015 cbosdonnat@suse.com
- Fixed virt-aa-helper bugs preventing virt-sandbox to work.
  24f3c2f-virt-aa-helper-fix-caps.patch
  61dab0f-virt-aa-helper-renaming.patch
  a55a5e7-virt-aa-helper-log.patch
  e44bcae-virt-aa-helper-trailing-slash.patch
  bsc#936841
- Fixed crasher due to uninitialized values
  qemu-nbd-cleanup-fix.patch bsc#936841
* Thu Jul  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.17
  - parallels driver renamed to vz (Virtuozzo)
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
- spec: re-enable tests that have received upstream fixes and
  are now passing
* Wed Jun  3 2015 jfehlig@suse.com
- Remove unsupported settings in libvirtd.socket unit file when
  systemd version < 214
  libvirtd-systemd-socket.patch
  bsc#933043
- spec: always apply Apparmor and netcontrol patches
* Tue Jun  2 2015 jfehlig@suse.com
- spec: Add libvirtd.socket unit file to service_add_pre and
  service_del_postun macros
* Mon Jun  1 2015 jfehlig@suse.com
- Update to libvirt 1.2.16
  - Introduce pci-serial
  - Introduce virDomainSetUserPassword API
  - Introduce protected key mgmt ops
  - Add domain vmport feature
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches c0d3f608-libxl-soundhw.patch and
    8910e063-arch-caps.patch
  - Drop polkit-10-virt.rules in favor of upstream 50-libvirt.rules
* Wed May 20 2015 dmacvicar@suse.de
- qemu: fix regression defaulting to host arch
  8910e063-arch-caps.patch
  rhb#1219191
* Wed May  6 2015 jfehlig@suse.com
- spec: build libxl driver for aarch64 and remove useless
  'suse_version <= 1220' conditional
* Tue May  5 2015 jfehlig@suse.com
- libxl: support virtual sound devices in HVM domains
  c0d3f608-libxl-soundhw.patch
  bsc#875216
* Mon May  4 2015 jfehlig@suse.com
- Update to libvirt 1.2.15
  - Implement virDomainAddIOThread and virDomainDelIOThread
  - libxl: Introduce configuration file for libxl driver
  - Add VIR_DOMAIN_EVENT_ID_DEVICE_ADDED event
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches da33a1ac-lxc-init-statedir.patch and
    open-ns-files-readonly.patch
- spec file fixups for building --without-driver-modules
* Mon Apr 20 2015 cbosdonnat@suse.com
- boo#926765: add libvirt-daemon-driver-qemu dependency on
  libvirt-daemon-driver-storage.
* Thu Apr  9 2015 cbosdonnat@suse.com
- boo#926153: make sure /var/run/libvirt/lxc folder exists when
  starting the driver. da33a1ac-lxc-init-statedir.patch
- Fix lxc-enter-namespace for 3.19+ kernels.
  open-ns-files-readonly.patch
* Thu Apr  2 2015 jfehlig@suse.com
- Disable building wireshark dissector.  Commit 37397320
  requires wireshark pkgconfig, which SUSE wireshark packages
  do not provide.
- Disable building the legacy Xen driver since Xen no longer
  provides the xend toolstack.  Remove xend-specific patches
  while at it: fix-pci-attach-xen-driver.patch,
  xen-name-for-devid.patch
* Thu Apr  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.14
  - qemu: Implement memory device hotplug
  - Implement public API for virDomainPinIOThread
  - Implement public API for virDomainGetIOThreadsInfo
  - SRIOV NIC offload feature discovery
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop disable-hugepage-test.patch in favor of upstream fix
* Tue Mar 31 2015 jfehlig@suse.com
- Fix build on older distros containing a polkit package that lacks
  support for /etc/polkit-1/rules.d drop directory
* Wed Mar 25 2015 jfehlig@suse.com
- Disable interface driver if libnetcontrol cannot be initialized
  Modified libvirt-suse-netcontrol.patch
  boo#920551
* Mon Mar 16 2015 jfehlig@suse.com
- Fix crash in libnetcontrol-backed interface driver
  Modified libvirt-suse-netcontrol.patch
  boo#920551
* Thu Mar 12 2015 fcastelli@suse.com
- Instruct polkit to allow memebers of the 'libvirt' group to connect
  to libvirt without providing any password (bnc#920804)
- Added polkit-10-virt.rules to fix bnc#920804
* Wed Mar 11 2015 jfehlig@suse.com
- Change default setting of security_default_confined in
  /etc/libvirt/qemu.conf instead of in code.  Making the change in
  code changes the default behavior for all users, even those that
  have a custom security setup in their /etc/libvirt/qemu.conf.
  Modified suse-qemu-conf.patch
  bsc#921586
* Mon Mar  9 2015 cbosdonnat@suse.com
- Fixed a number of QEMU apparmor abstraction problems. bsc#921355
  apparmor-fixes.patch
* Mon Mar  2 2015 jfehlig@suse.com
- Update to libvirt 1.2.13
  - qemu: improved support for host and guest NUMA
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Tue Jan 27 2015 jfehlig@suse.com
- Update to libvirt 1.2.12
  - CVE-2015-0236: qemu: Check ACLs when dumping security info
    from snapshots
  - CVE-2015-0236: qemu: Check ACLs when dumping security info
    from save image
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 30c6aecc-apparmor-lib64.patch,
    apparmor-xen-fixup.patch, apparmor-allow-helpers.patch,
    apparmor-tck-raw-packets.patch
  - Disable a hugepage test that is failing on ppc, ppc64, and
    ppc64le architectures - disable-hugepage-test.patch
* Tue Jan 20 2015 cbosdonnat@suse.com
- Fixed patches to pass make syntax-check
* Tue Jan 20 2015 mlatimer@suse.com
- Apparmor profile regression breaks Xen domains. bsc#913799
  apparmor-xen-fixup.patch
  apparmor-allow-helpers.patch
  apparmor-tck-raw-packets.patch
* Mon Jan  5 2015 cbosdonnat@suse.com
- Replaced hard to maintain install-apparmor-profiles.patch
  by upstreamed 30c6aecc-apparmor-lib64.patch.
- Reformatted libvirt.spec and libvirtd.init to pass upstream make
  syntax-check
* Sat Dec 27 2014 Led <ledest@gmail.com>
- fix bashisms in libvirt-guests.sh script
- update patches:
  + libvirt-guests-init-script.patch
* Mon Dec 15 2014 cbosdonnat@suse.com
- Update to libvirt 1.2.11
  - Implement public API for virDomainGetFSInfo
  - qemu: Add define for the new throttle options
  - CVE-2014-8131: Fix possible deadlock and segfault in qemuConnectGetAllDomainStats()
  - CVE-2014-7823: dumpxml: security hole with migratable flag
- Drop upstream patches: 2222123-virt-aa-helper-crash.patch,
  433b427-iplink-name.patch,
  52691f99-qemu-mig-crash.patch,
  72fecf1-lxc-resolve-symlinks.patch,
  b1674ad5-CVE-2014-7823.patch,
  ba9b7252-sys-net-rw.patch,
  c264eea-virt-aa-helper-sandbox.patch,
  e50457d-lxc-unmount-check.patch,
  cgroup-all-devices.patch,
  libvirt-ppc64le-support.patch
* Wed Dec 10 2014 cbosdonnat@suse.com
- Get /proc/sys/net/ipv[46] read-write for wicked to work in
  containers. bsc#904432. ba9b7252-sys-net-rw.patch
- Fixed allowing devices for containers.
  cgroup-all-devices.patch
* Wed Dec  3 2014 jfehlig@suse.com
- qemu: Fix crash in tunnelled migration
  52691f99-qemu-mig-crash.patch
  boo#908008
* Thu Nov 20 2014 cbosdonnat@suse.com
- Fix potential crasher in virt-aa-helper
  2222123-virt-aa-helper-crash.patch
- ip link add now needs the 'name' parameter.
  433b427-iplink-name.patch
- Fixes for virt-sandbox-service to work:
  - Allow adding virt-sandbox service config to apparmor rules.
    c264eea-virt-aa-helper-sandbox.patch
  - fix symlink resolving for containers to start.
    72fecf1-lxc-resolve-symlinks.patch
  - fix unmounting file system if it contains the source to mount.
    e50457d-lxc-unmount-check.patch
* Tue Nov 18 2014 cbosdonnat@suse.com
- Remove security_driver = "none" in qemu config. This completely
  disabled all security drivers instead of probing them.
- Changed default value of QEMU's security_default_confined to 0 to
  keep QEMU domains unconfined by default.
* Tue Nov 11 2014 jfehlig@suse.com
- CVE-2014-7823: dumpxml: security hole with migratable flag
  b1674ad5-CVE-2014-7823.patch
  bsc#904176
* Thu Nov  6 2014 cbosdonnat@suse.com
- Fix Qemu AppArmor abstraction.
  - qemu-block.so was denied on x86_64. install-apparmor-profiles.patch
  - Temporary fix access to screenshot temporary file. bsc#904426.
    qemu-apparmor-screenshot.patch
* Mon Nov  3 2014 jfehlig@suse.com
- Update to libvirt 1.2.10
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Mon Oct 27 2014 cbosdonnat@suse.com
- Added package wireshark-plugin-libvirt to provide the wireshark
  dissector for the libvirt RPC protocol
* Thu Oct  2 2014 jfehlig@suse.com
- spec: Remove gpg-offline build dependency and use of gpg_verify
  to verify tarball since this task can be performed by source
  services
* Wed Oct  1 2014 jfehlig@suse.com
- Update to libvirt 1.2.9
  - Introduce virNodeAllocPages
  - event: introduce new event for tunable values
  - Add support for fetching statistics of completed jobs
  - CVE-2014-3657: domain_conf: fix domain deadlock
  - CVE-2014-3633: qemu: blkiotune: Use correct definition when
    looking up disk
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 3e745e8f-CVE-2014-3633.patch,
    libvirt-guests-wait-for-ntp.patch
- Verify tarball with associated .asc file
  Add: libvirt.keyring, libvirt-1.2.9.tar.gz.asc
  Use upstream .gz tarball instead of locally generated .bz2
* Fri Sep 19 2014 jfehlig@suse.com
- CVE-2014-3633: Use correct definition when looking up disk in
  qemu blkiotune
  3e745e8f-CVE-2014-3633.patch
  bnc#897783
* Wed Sep 10 2014 jfehlig@suse.com
- spec: do not require dmidecode on older code 11
* Mon Sep  8 2014 jfehlig@suse.com
- Wait for ntp service before running libvirt-guests
  libvirt-guests-wait-for-ntp.patch
  bnc#895194
* Thu Sep  4 2014 jfehlig@suse.com
- Canonicalize host arch name ppc64le to ppc64
  ppc64le-canonical-name.patch
  bnc#894956
* Tue Sep  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.8
  - virDomainBlockCopy with XML destination, typed params
  - Introduce API for retrieving bulk domain stats
  - Introduce virDomainOpenGraphicsFD API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Mon Sep  1 2014 cbosdonnat@suse.com
- bnc#893999: remove mount rules from libvirt-lxc apparmor
  abstraction file as those aren't handled by our kernel.
  apparmor-no-mount.patch
* Fri Aug 29 2014 mlatimer@suse.com
- bnc#894232 - Update apparmor profile to allow raw packets
  install-apparmor-profiles.patch
* Wed Aug 20 2014 ro@suse.de
- remove not necessary hunks from libvirt-ppc64le-support.patch
- move new patches to section for to be upstreamed
* Tue Aug 19 2014 ro@suse.de
- add patch: libvirt-power8-models.patch
  add current power8 cpu models to map
* Tue Aug 19 2014 ro@suse.de
- add patch: libvirt-ppc64le-support.patch
  add preliminary ppc64le support to libvirt
* Fri Aug  8 2014 cyliu@suse.com
- bnc#820399 - virsh blockcopy should refuse identical device
  blockcopy-check-dst-identical-device.patch
* Mon Aug  4 2014 jfehlig@suse.com
- Update to libvirt 1.2.7
  - Introduce virConnectGetDomainCapabilities
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: dba3432b-virt-lxc-convert-fix.patch,
    9b1e4cd5-skip-useless-apparmor-files.patch,
    9265f8ab-apparmor-lxc-rework.patch,
    add-nocow-to-vol-xml.patch,
    lxc-keep-caps-feature.patch,
    lxc-keep-caps-feature-conversion.patch,
    lxc-keep-caps-feature-doc.patch,
    lxc-net-target-name.patch,
    lxc-net-target-name-conversion.patch,
    lxc-net-target-name-doc.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- lxc AppArmor profile now only restricting potentially dangerous
  accesses. fdo#886460
- Add virt-lxc-convert to libvirt-daemon-driver-lxc package
- added patches:
  * 9265f8ab-apparmor-lxc-rework.patch
  * 9b1e4cd5-skip-useless-apparmor-files.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- virt-lxc-convert: force free to output values in bytes
- added patches:
  * dba3432b-virt-lxc-convert-fix.patch
* Wed Jul 16 2014 cbosdonnat@suse.com
- lxc: allow setting a custom name for container NICs as LXC is
  is able to do it.
  lxc-net-target-name.patch,
  lxc-net-target-name-conversion.patch,
  lxc-net-target-name-doc.patch
* Wed Jul  2 2014 jfehlig@suse.com
- Move 'Requires' of qemu from libvirt-daemon-qemu subpackage to
  libvirt-daemon-driver-qemu
  bnc#885267
* Wed Jul  2 2014 jfehlig@suse.com
- Temporarily disable virt-aa-helper-test, which fails in Factory
* Wed Jul  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.6
  - libxl: add migration support and fixes
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patch libxl-migration-support.patch
  - Drop ia64-clone.patch since libvirt is not built for IA64
* Wed Jun 25 2014 cbosdonnat@suse.com
- lxc-keep-caps-feature.patch: allow to keep/drop additional
  capabilities for LXC containers. bnc#881465
- lxc-keep-caps-feature-conversion.patch: convert lxc.cap.drop to
  the new domain configuration.
- lxc-keep-caps-feature-doc.patch: documentation for the new feature.
* Mon Jun  2 2014 jfehlig@suse.com
- Disable failing virportallocatortest on aarch64
* Mon Jun  2 2014 jfehlig@suse.com
- Update to libvirt 1.2.5
  - Introduce virDomain{Get,Set}Time APIs
  - Introduce virDomainFSFreeze() and virDomainFSThaw() public API
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches:
    b98bf811-add-paravirt-shutdown-flag.patch,
    c4fe29f8-use-shutdown-flag.patch,
    da744120-use-reboot-flag.patch,
    d6b27d3e-CVE-2014-0179.patch,
    fd43d1f8-libxl-iface-hostdev.patch,
    99f50208-managed-hostdev-iface.patch,
    292d3f2d-libselinux-build-fix1.patch,
    b109c097-libselinux-build-fix2.patch
* Wed May 28 2014 jfehlig@suse.com
- Add upstream patches that fix build with libselinux 2.3
  Added: 292d3f2d-libselinux-build-fix1.patch,
    b109c097-libselinux-build-fix2.patch
  Dropped: libselinux-build-fix.patch
* Wed May 28 2014 cbosdonnat@suse.com
- Fix the build breakers brought by libselinux 2.3.
  libselinux-build-fix.patch
* Tue May 20 2014 jfehlig@suse.com
- spec: libvirt-daemon package owns /etc/libvirt, not libvirt-client
  bnc#878056
* Mon May 12 2014 jfehlig@suse.com
- libxl: Fix <interface type='hostdev'> syntax for SR-IOV devices
  fd43d1f8-libxl-iface-hostdev.patch,
  99f50208-managed-hostdev-iface.patch
* Tue May  6 2014 jfehlig@suse.com
- Update to libvirt 1.2.4
  - Primarily a bug-fix release.  See http://libvirt.org/news.html
    for a detailed list of bug fixes and improvements
  - Drop upstream patches:
    0e0c1a74-domid-fix.patch, 7a1452f5-libxl-empty-cdrom.patch
- libxl: Support ACPI shutdown event
  b98bf811-add-paravirt-shutdown-flag.patch,
  c4fe29f8-use-shutdown-flag.patch, da744120-use-reboot-flag.patch
  bnc#872777
- libx: Support migration
  libxl-migration-support.patch
  bnc#875193
* Mon May  5 2014 jfehlig@suse.com
- CVE-2014-0179: Don't expand entities when parsing XML
  d6b27d3e-CVE-2014-0179.patch
  bnc#873705
* Wed Apr 16 2014 dmueller@suse.com
- blacklist one more unit test for qemu_linux_user builds
* Tue Apr  8 2014 jfehlig@suse.com
- libxl: Set disk format for empty cdrom device
  0e0c1a74-domid-fix.patch, 7a1452f5-libxl-empty-cdrom.patch
  bnc#872517
* Mon Apr  7 2014 cyliu@suse.com
- Fate#315125: add NOCOW flag
  add-nocow-to-vol-xml.patch
* Wed Apr  2 2014 cbosdonnat@suse.com
- Removed libxl-hvm-vnc.patch: went upstream in another form
* Wed Apr  2 2014 cbosdonnat@suse.com
- Update to libvirt 1.2.3
  - add new virDomainCoreDumpWithFormat API
  - conf: Introduce virDomainDeviceGetInfo API
  - more features and fixes on bhyve driver
  - lot of cleanups and improvement on the Xen driver
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Fri Mar 14 2014 jfehlig@suse.com
- Add /usr/sbin/rc{libvirtd,virtlockd,libvirt-guests} symlinks
  to preserve backwards compatibility
  bnc#868190
* Tue Mar  4 2014 jfehlig@suse.com
- Improve lock manager comments in qemu.conf
  Updated suse-qemu-conf.patch
* Tue Mar  4 2014 speilicke@suse.com
- Create /etc/libvirt/hooks to allow using hook scripts
* Mon Mar  3 2014 jfehlig@suse.com
- Update to libvirt 1.2.2
  - add LXC from native conversion tool
  - vbox: add support for v4.2.20+ and v4.3.4+
  - CVE-2013-6456 (bnc#857490)
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 37564b47-xend-parse-response.patch,
    4f20084-fix-apparmor-install-patch.patch
  - Add local disable-virCgroupGetPercpuStats-test.patch to disable
    failing virCgroupGetPercpuStats test in 'make check'
* Mon Feb 24 2014 jfehlig@suse.com
- daemon-qemu: Require qemu instead of kvm to align with
  recent changes to the qemu package structure
* Fri Feb 14 2014 jfehlig@suse.com
- spec: fix dependencies of daemon-config-network and
  daemon-config-nwfilter subpackages.  Influenced by upstream
  commits cf76c4b3 and dca5ce4c
* Fri Feb 14 2014 jfehlig@suse.com
- Remove libvirtd, virtlockd, and libvirt-guests init scripts when
  using systemd
  bnc#863540
* Wed Feb 12 2014 cbosdonnat@suse.com
- Fix the path to libvirtd AppArmor template profile
* Wed Jan 29 2014 jfehlig@suse.com
- Fix parsing xend http response
  37564b47-xend-parse-response.patch
  rhb#1055165
* Wed Jan 22 2014 jfehlig@suse.com
- Add CAP_SYS_PACCT capability to libvirtd AppArmor profile
  Modified install-apparmor-profiles.patch
  bnc#817407
* Tue Jan 21 2014 jfehlig@suse.com
- Fix build on code 11
- Fix rpmlint warning
* Tue Jan 21 2014 jfehlig@suse.com
- Following the upstream pattern, introduce the
  daemon-config-network subpackage to handle defining the default
  network
  bnc#859041
* Fri Jan 17 2014 jfehlig@suse.com
- Update to libvirt 1.2.1
  - CVE-2014-0028, CVE-2014-1447, CVE-2013-6458, CVE-2013-6457,
    CVE-2013-6436
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Dropped upstream patches: 5e397d9c-test-fix-dbus-crash.patch,
    78af457e-fix-virnettlscontexttest.patch,
    9faf3f29-LXC-memtune.patch, f8c1cb90-CVE-2013-6436.patch,
    libxl-hvm-nic.patch
* Fri Dec 27 2013 jfehlig@suse.com
- Ignore 'make check' on older, code 11 base
* Thu Dec 26 2013 cbosdonnat@suse.com
- Fixed and reenabled unit tests. bnc#854694
* Fri Dec 20 2013 jfehlig@suse.com
- Remove dependency on pm-utils from libvirt-client
  bnc#856381
* Fri Dec 20 2013 jfehlig@suse.com
- CVE-2013-6436: Fix crashes in lxc memtune code, one of which
  results in DoS
  f8c1cb90-CVE-2013-6436.patch, 9faf3f29-LXC-memtune.patch
  bnc#854486
* Fri Dec  6 2013 jfehlig@suse.com
- More adjustments to the spec file to fix package dependency
  issues
  bnc#848918
* Fri Dec  6 2013 jfehlig@suse.com
- Update to libvirt 1.2.0
  - Add support for gluster pool
  - Separation of python binding
  - vbox: add support for 4.3 APIs
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Updated and renamed clone.patch to ia64-clone.patch
- Enabled numad support for openSUSE >= 13.1
* Wed Dec  4 2013 jfehlig@suse.com
- Link with same versions of libnl used by netcontrol to prevent
  crashing libvirtd on start
* Wed Dec  4 2013 jfehlig@suse.com
- Add '/etc/sasl2' to libvirt-client file list to fix Factory build
* Wed Nov 27 2013 jfehlig@suse.com
- Fix starting of libvirtd when NetworkManager is enabled
  Modified libvirt-suse-netcontrol.patch
* Tue Nov 26 2013 jfehlig@suse.com
- Allow execution of libvirt hook scripts in /etc/libvirt/hooks/
  in libvirtd AppArmor profile
* Wed Nov 20 2013 jfehlig@suse.com
- Update to libvirt 1.1.4
  - Add support for AArch64 architecture
  - Various improvements on test code and test driver
  - Don't link virt-login-shell against libvirt.so
  - Close all non-stdio FDs in virt-login-shell
  - Only allow 'stderr' log output when running setuid
  - Fix perms for virConnectDomainXML{To,From}Native
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: e7f400a1-CVE-2013-4296.patch,
    2dba0323-CVE-2013-4297.patch, db7a5688-CVE-2013-4311.patch,
    e65667c0-CVE-2013-4311.patch, 922b7fda-CVE-2013-4311.patch,
    e4697b92-CVE-2013-4311.patch, 8294aa0c-CVE-2013-4399.patch,
    484cc321-fix-spice-migration.patch,
    79552754-libvirtd-chardev-crash.patch,
    57687fd6-CVE-2013-4401.patch, ae53e5d1-CVE-2013-4400.patch,
    8c3586ea-CVE-2013-4400.patch, b7fcc799a-CVE-2013-4400.patch,
    3e2f27e1-CVE-2013-4400.patch, 5a0ea4b7-CVE-2013-4400.patch,
    843bdb2f-CVE-2013-4400.patch,
    bd773e74-lxc-terminate-machine.patch,
    e350826c-python-fix-fd-passing.patch
* Tue Nov 19 2013 jfehlig@suse.com
- Allow execution of Xen binaries in /usr/lib{,64}/xen/bin in
  libvirtd AppArmor profile
  bnc#849524
* Tue Nov 19 2013 jfehlig@suse.com
- Require libvirt-daemon-<hypervisor> in the main libvirt package
  for each supported hypervisor
  bnc#850882
* Mon Nov  4 2013 jfehlig@suse.com
- Fix initialization of libxl NIC devices
  libxl-hvm-nic.patch
  bnc#848918
* Wed Oct 30 2013 jfehlig@suse.com
- Fix typo in libvirtd apparmor profile which prevented the profile
  from loading
  bnc#848216
* Fri Oct 25 2013 jfehlig@suse.com
- libxl driver: fix initialization of VNC and SDL info for
  HVM domains
  libxl-hvm-vnc.patch
  bnc#847566
- Allow libvirtd apparmor profile to access /etc/xen/scripts/*
* Wed Oct 23 2013 jfehlig@suse.com
- Fix file descriptor passing in python bindings
  e350826c-python-fix-fd-passing.patch
  rhb#1021434
* Tue Oct 22 2013 cbosdonnat@suse.com
- Have systemd terminate the machine as a workaround of fdo#68370
  bd773e74-lxc-terminate-machine.patch
  bnc#842834
* Tue Oct 22 2013 jfehlig@suse.com
- Spec file fixes to only package libvirt-login-shell when
  building the LXC driver
* Mon Oct 21 2013 jfehlig@suse.com
- CVE-2013-4400: Unsantized use of env variables allows privilege
  escalation via virt-login-shell
  ae53e5d1-CVE-2013-4400.patch, 8c3586ea-CVE-2013-4400.patch,
  b7fcc799a-CVE-2013-4400.patch, 3e2f27e1-CVE-2013-4400.patch,
  5a0ea4b7-CVE-2013-4400.patch, 843bdb2f-CVE-2013-4400.patch
  bnc#837609
- CVE-2013-4401: Fix perms for virConnectDomainXML{To,From}Native
  57687fd6-CVE-2013-4401.patch
  bnc#845704
* Fri Oct 18 2013 jfehlig@suse.com
- Move hypervisor-specific files out of libvirt-daemon package
  and into libvirt-daemon-<hypervisor> subpackage
  bnc#845851
- conf: Don't crash on invalid chardev source definition
  79552754-libvirtd-chardev-crash.patch
  bnc#845704, rhb#1012196
* Thu Oct 17 2013 jfehlig@suse.com
- Use newer libnl3 instead of libnl-1_1
  bnc#845540
* Tue Oct 15 2013 jfehlig@suse.com
- Move virt-login-shell to new subpackage libvirt-login-shell,
  requiring users to opt-in for this setuid binary.  Note: For now,
  virt-login-shell will not have setuid permissions, pending
  resolution of bnc#837609
* Tue Oct 15 2013 jfehlig@suse.com
- qemu: Fix seamless SPICE migration
  484cc321-fix-spice-migration.patch
  bnc#842301
* Tue Oct 15 2013 jfehlig@suse.com
- CVE-2013-4399: Fix crash in libvirtd when events are registered
  and ACLs active
  8294aa0c-CVE-2013-4399.patch
  bnc#844052, bnc#842300
* Mon Oct 14 2013 jfehlig@suse.com
- Update the stale gettext BuildRequires and Requires dependencies
  in the spec file
  bnc#841325
* Mon Oct 14 2013 jfehlig@suse.com
- virt-aa-helper apparmor profile was denying read access to
  /proc/$PID/*.  Give read accesss to these files.
  Updated install-apparmor-profiles.patch
  bnc#841720
* Mon Oct 14 2013 jfehlig@suse.com
- libvirtd apparmor profile was denying access to
  /usr/lib/xen/bin/qemu-system-i386, which is now the default
  emulator used with Xen guests
  Updated install-apparmor-profiles.patch
  bnc#845648
* Thu Oct  3 2013 jfehlig@suse.com
- Fix condrestart|try-restart invocation of virtlockd init script
  Modifed virtlockd-init-script.patch
* Tue Sep 17 2013 jfehlig@suse.com
- CVE-2013-4311: Add support for using 3-arg pkcheck syntax for
  process
  db7a5688-CVE-2013-4311.patch, e65667c0-CVE-2013-4311.patch,
  922b7fda-CVE-2013-4311.patch, e4697b92-CVE-2013-4311.patch
  bnc#836931
* Thu Sep  5 2013 jfehlig@suse.com
- CVE-2013-4296: Fix crash in remoteDispatchDomainMemoryStats
  e7f400a1-CVE-2013-4296.patch
  bnc#838638
- CVE-2013-4297: Fix crash in virFileNBDDeviceAssociate
  2dba0323-CVE-2013-4297.patch
  bnc#838642
* Tue Sep  3 2013 jfehlig@suse.com
- Update to libvirt 1.1.2
  - various improvements to libxl driver
  - systemd integration improvements
  - Add flag to BaselineCPU API to return detailed CPU features
  - Introduce a virt-login-shell binary
  - conf: add startupPolicy attribute for harddisk
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: bcef0f01-libxl-console.patch,
    9d0557b9-legacy-xen-double-free.patch,
    d7a45bf2-legacy-xen-dumpxml.patch, 0e671a16-CVE-2013-4239.patch
  - Includes fixes for bnc#837530, bnc#837531, bnc#837999
* Tue Aug 13 2013 jfehlig@suse.com
- Fix memory corruption in legacy Xen driver
  0e671a16-CVE-2013-4239.patch
  bnc#834598
- Upstream patches to fix dumpxml in legacy Xen driver
  9d0557b9-legacy-xen-double-free.patch,
  d7a45bf2-legacy-xen-dumpxml.patch
* Wed Jul 31 2013 jfehlig@suse.com
- Backport upstream patch implementing domainOpenConsole in the
  libxl driver.  Allows 'virsh console dom-name' to work with
  Xen libxl toolstack.
  bcef0f01-libxl-console.patch
* Tue Jul 30 2013 jfehlig@suse.com
- Update to libvirt 1.1.1
  - Adding device removal or deletion events
  - Introduce new domain create APIs to pass pre-opened FDs to LXC
  - Add interface versions for Xen 4.3
  - Add new public API virDomainSetMemoryStatsPeriod
  - Various LXC improvements
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: f38c8185-CVE-2013-2230.patch,
    fd2e3c4c-xen-sysctl-domctl.patch, dfc69235-CVE-2013-4153.patch,
    96518d43-CVE-2013-4154.patch, fe89fd3b-storage-pool-deadlock.patch
  - Drop relax-qemu-usergroup-check.patch - no longer needed
    after hypervisor-specific daemon package split
* Mon Jul 22 2013 jfehlig@suse.com
- Unlock the storage volume object after looking it up
  fe89fd3b-storage-pool-deadlock.patch
  rhb#980676
* Mon Jul 22 2013 jfehlig@suse.com
- CVE-2013-4153: Fix double free of returned JSON array in
  qemuAgentGetVCPUs()
  dfc69235-CVE-2013-4153.patch
- CVE-2013-4154: Prevent crash of libvirtd without guest agent
  configuration
  96518d43-CVE-2013-4154.patch
  bnc#830498
* Wed Jul 17 2013 jfehlig@suse.com
- Fix legacy xen driver with Xen 4.3
  fd2e3c4c-xen-sysctl-domctl.patch
* Wed Jul 10 2013 jfehlig@suse.com
- CVE-2013-2230: Fix crash when multiple event callbacks were
  registered
  f38c8185-CVE-2013-2230.patch
  bnc#827801
* Wed Jul 10 2013 jfehlig@suse.com
- Update to libvirt 1.1.0
  - Extensible migration APIs
  - Add a policy kit access control driver
  - various improvements in the Xen and libxl drivers
  - improve networking support on BSD
  - agent based vCPU hotplug support
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: 244e0b8c-CVE-2013-2218.patch
* Mon Jul  8 2013 jfehlig@suse.com
- Only require lzop if suse_version > 1210
* Wed Jul  3 2013 jfehlig@suse.com
- Fix typo in spec file
* Wed Jul  3 2013 jfehlig@suse.com
- Enable support for netcontrol by default
- Only require libvirt-daemon-driver-interface when building the
  interface driver
* Mon Jul  1 2013 jfehlig@suse.com
- CVE-2013-2218: Fix crash listing network interfaces with filters
  244e0b8c-CVE-2013-2218.patch
* Tue Jun 11 2013 jfehlig@suse.com
- Add xencommons as 'Wanted' in the systemd libvirtd service file
  systemd-service-xen.patch
  bnc#820888
* Mon Jun 10 2013 jfehlig@suse.com
- Fix build for SLE11 SP2
* Fri Jun  7 2013 jfehlig@suse.com
- Add a README to the empty packages.  Provides some info about
  their purpose and satisfies suse-filelist-empty check.
  Drop rpmlintrc
* Fri Jun  7 2013 jfehlig@suse.com
- Fix typo in spec file: devel package requires doc package, not
  docs
* Thu Jun  6 2013 jfehlig@suse.com
- Add rpmlintrc to get around suse-filelist-empty error on
  older distros.
* Thu Jun  6 2013 jfehlig@suse.com
- Refactor libvirt spec file to create subpackages for the various
  libvirtd components.  This allows installing a libvirtd tailored
  for the underlying virtualizer.  E.g. on a KVM/QEMU virtualizer
  only the libvirt-daemon-qemu package needs installed.
  Similarly, only libvirt-daemon-xen on a Xen virtualizer and
  libvirt-daemon-lxc on LXC.
* Tue Jun  4 2013 jfehlig@suse.com
- Update to libvirt 1.0.6
  - Move VirtualBox driver into libvirtd
  - Support for static routes on a virtual bridge
  - Various improvement for hostdev SCSI support
  - Switch to VIR_STRDUP and VIR_STRNDUP
  - Various cleanups and improvement in Xen and LXC drivers
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: f493d83f-cgroup-swap-control.patch,
    486a86eb-cgroups-docs.patch, 0ced83dc-cgroup-escape-dot.patch,
    bbe97ae9-no-cgroups.patch, c2cf5f1c-no-cgroups-fix.patch,
    95c6cc34-selinux.patch
* Tue May 21 2013 jfehlig@suse.com
- Update to libvirt 1.0.5.1 stable release
  - qemu: Fix cgroup handling when setting VCPU BW
  - daemon: fix leak after listing all volumes
  - Fix iohelper usage with streams opened for read
  - util: fix virFileOpenAs return value and resulting error logs
  - iscsi: don't leak portal string when starting a pool
  - don't mention disk controllers in generic controller errors
  - conf: don't crash on a tpm device with no backends
  - qemu: allocate network connections sooner during domain startup
  - Make detect_scsi_host_caps a function on all architectures
  - Fix release of resources with lockd plugin
  - Fix potential use of undefined variable in remote dispatch code
  - Fix F_DUPFD_CLOEXEC operation args
  - qemu: fix stupid typos in VFIO cgroup setup/teardown
  - network: fix network driver startup for qemu:///session
- Remove patches that are included in the 1.0.5.1 release
  0471637d-cgroups-vcpu-bw.patch, a2214c52-iohelper.patch,
  ca697e90-CVE-2013-1962.patch
* Mon May 20 2013 jfehlig@suse.com
- Don't mount selinux fs in LXC if selinux is disabled
  95c6cc34-selinux.patch
  bnc#814680
* Sat May 18 2013 jfehlig@suse.com
- fix leak after listing all volumes - CVE-2013-1962
  ca697e90-CVE-2013-1962.patch
  bnc#820397
- Fix iohelper usage with streams opened for read
  a2214c52-iohelper.patch
- Cope with missing swap cgroup controls
  f493d83f-cgroup-swap-control.patch
  bnc#819976
- Fix cgroup handling when setting VCPU BW
  0471637d-cgroups-vcpu-bw.patch
  rhb#963592
- Escape a leading '.' with '_' in the cgroup names
  0ced83dc-cgroup-escape-dot.patch
- Add missing documentation on new cgroup layout
  486a86eb-cgroups-docs.patch
- Another fix related to systems with no cgroups
  c2cf5f1c-no-cgroups-fix.patch
  bnc#819963
* Thu May 16 2013 jfehlig@suse.com
- Fix botched backport of commit bbe97ae9
* Mon May 13 2013 jfehlig@suse.com
- Fix starting domains when kernel has no cgroups support
  bbe97ae9-no-cgroups.patch
* Thu May  2 2013 jfehlig@suse.com
- Update to libvirt 1.0.5
  - PPC64: Add NVRAM device
  - Add XML config for resource partitions
  - Add support for TPM
  - NPIV storage migration support
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
* Tue Apr  2 2013 jfehlig@suse.com
- Update to libvirt 1.0.4
  - qemu: support passthrough for iscsi disks
  - various S390 improvements
  - various LXC bugs fixes and improvements
  - add API for thread cancellation
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: ce4557c3-apparmor-tapfd-label.patch
    libvirt-iptables-1.4.18.diff
* Sun Mar 24 2013 seife+obs@b1-systems.com
- add libvirt-iptables-1.4.18.diff, fix masquerading with iptables
  v1.4.18 (--state match is deprectated, use conntrack instead)
* Fri Mar  8 2013 jfehlig@suse.com
- Fix PCI device attach for xen HVM domains
  fix-pci-attach-xen-driver.patch
  FATE#313570
* Fri Mar  8 2013 jfehlig@suse.com
- Apparmor security driver: Ensure tapfd's are labled when
  generating the guest profile.
  Modified install-apparmor-profiles.patch, added upstream patch
  ce4557c3-apparmor-tapfd-label.patch
  bnc#807940
* Thu Mar  7 2013 jfehlig@suse.com
- Grant permission to use datagram packets in libvirtd apparmor
  profile.
  Remove AF_PACKET.patch, modify install-apparmor-profiles.patch
  bnc#801145
* Wed Mar  6 2013 jfehlig@suse.com
- Add 'managed' PCI passthrough support to legacy xen driver
  support-managed-pci-xen-driver.patch
  FATE#313570
* Tue Mar  5 2013 jfehlig@suse.com
- Update to libvirt 1.0.3
  - Introduce virDomainMigrate*CompressionCache APIs
  - Introduce virDomainGetJobStats API
  - Add basic support for VDI images
  - Introduce API virNodeDeviceLookupSCSIHostByWWN
  - Various locking improvements
  - Many incremental improvements and bug fixes, see
    http://libvirt.org/news.html
  - Drop upstream patches: a6b8bae5-python-generator-fix1.patch,
    25ea8e47-python-generator-fix2.patch,
    567779e5-libxl-default-disk-backend.patch
* Fri Mar  1 2013 jfehlig@suse.com
- Fix path to qemu-bridge-helper in libvirt-qemu apparmor profile
  Modified install-apparmor-profiles.patch
* Mon Feb 25 2013 jfehlig@suse.com
- Fix detach of managed PCI devices from inactive domains.
  Detected while running test cases for FATE #313570.
  Modified xen-name-for-devid.patch
* Thu Feb 21 2013 jfehlig@suse.com
- spec: Fix installation of default network
* Wed Feb 20 2013 jfehlig@suse.com
- Fix default setting of backend field of libxl_device_disk
  567779e5-libxl-default-disk-backend.patch
  rhb#912488
* Tue Feb 12 2013 jfehlig@suse.com
- Fix build on IA64
  Modified clone.patch
* Thu Feb  7 2013 jfehlig@suse.com
- Fix error handling in python bindings
  a6b8bae5-python-generator-fix1.patch
  25ea8e47-python-generator-fix2.patch
  bnc#802619
* Sun Feb  3 2013 crrodriguez@opensuse.org
- Require modutils instead of module-init-tools.
* Wed Jan 30 2013 jfehlig@suse.com
- Update to libvirt 1.0.2
  - LXC improvements
  - S390 architecture improvements
  - Power architecture improvements
  - large Coverity report cleanups and associated bug fixes
  - virTypedParams* APIs to help with those data structures
  - libxenlight driver improvements
  - Fixes CVE-2013-0170, bnc#800976
  - Drop upstream patches: 68e7bc45-libxl-link-fix.patch,
    462a6962-script-fixes1.patch, cb854b8f-script-fixes2.patch,
    5ec4b22b-script-fixes3.patch, a1fd56cb-script-fixes4.patch,
    66ff2ddc-virtlockd-systemd-file-perms.patch
* Tue Jan 22 2013 jfehlig@suse.com
- Unconditionally build sanlock support
  bnc#799262
* Tue Jan 22 2013 jfehlig@suse.com
- Fix interface management functions that were broken when
  rebasing libvirt-suse-netcontrol.patch
  bnc#799444 (SLES bug that affect Factory too)
* Sat Jan  5 2013 jfehlig@suse.com
- Update to libvirt 1.0.1
  - Introduce virtlockd daemon
  - parallels: add disk and network device support
  - Add virDomainSendProcessSignal API
  - Introduce virDomainFSTrim() public API
  - add fuse support for libvirt lxc
  - Add Gluster protocol as supported network disk backend
  - various snapshot improvements
- Add upstream patches to fix bugs in 1.0.1
  66ff2ddc-virtlockd-systemd-file-perms.patch,
  462a6962-script-fixes1.patch, cb854b8f-script-fixes2.patch,
  5ec4b22b-script-fixes3.patch, a1fd56cb-script-fixes4.patch,
  68e7bc45-libxl-link-fix.patch
- Rework SUSE patches for the various init scripts
  Dropped use-init-script-redhat.patch and added
  libvirtd-init-script.patch, libvirt-guests-init-script.patch,
  and virtlockd-init-script.patch
* Fri Nov  2 2012 jfehlig@suse.com
- Update to libvirt 1.0.0
  - virNodeGetCPUMap: Define public API
  - Add systemd journal support
  - Add a qemu capabilities cache manager
  - USB migration support
  - various improvement and fixes when using QMP QEmu interface
  - Support for Xen 4.2 in legacy xen driver
  - Lot of localization enhancements
  - Drop upstream patches: 371ddc98-xen-sysctl-9.patch,
    416eca18-xenstore-header-fix.patch,
    f644361b-virCommand-env.patch, 2b32735a-virCommand-env.patch,
    9785f2b6-fix-xen-sysctl9.patch
* Tue Oct 23 2012 jfehlig@suse.com
- Fix Xen sysctl version 9 support
  9785f2b6-fix-xen-sysctl9.patch
* Thu Oct 11 2012 jfehlig@suse.com
- Add upstream patches to support latest libguestfs
  f644361b-virCommand-env.patch
  2b32735a-virCommand-env.patch
* Thu Sep 27 2012 jfehlig@suse.com
- Fix build when using -werror
  416eca18-xenstore-header-fix.patch
* Wed Sep 26 2012 jfehlig@suse.com
- Support Xen sysctl version 9
  371ddc98-xen-sysctl-9.patch
  bnc#781425
* Tue Sep 25 2012 jfehlig@suse.com
- Temporarily disable building libxl driver.  The current
  implementation does not support libxl in Xen 4.2.
* Tue Sep 25 2012 jfehlig@suse.com
- Update to libvirt 0.10.2
  - network: define new API virNetworkUpdate
  - add support for QEmu sandbox support
  - blockjob: add virDomainBlockCommit
  - node_memory: Define the APIs to get/set memory parameters
  - list: Define new API virConnectListAllSecrets
  - list: Define new API virConnectListAllNWFilter
  - list: Define new API virConnectListAllNodeDevices
  - list: Define new API virConnectListAllInterfaces
  - list: Define new API virConnectListAllNetworks
  - list: Define new API virStoragePoolListAllVolumes
  - list: Define new API virStorageListAllStoragePools
  - parallels: add support of containers to the driver
  - Add PMSUSPENDED life cycle event
  - Add per-guest S3/S4 state configuration
  - qemu: Support for Block Device IO Limits
* Fri Sep  7 2012 jfehlig@suse.com
- Update to libvirt 0.10.1
  - Bug fix release for critical bugs in 0.10.0
  - Drop upstream patch f781e276-xen-driver-fix.patch
* Fri Aug 31 2012 jfehlig@suse.com
- Update to libvirt 0.10.0
  - agent: add qemuAgentArbitraryCommand()
  - Introduce virDomainPinEmulator and virDomainGetEmulatorPinInfo
  - network: use firewalld instead of iptables, when available
  - network: make network driver vlan-aware
  - esx: Implement network driver
  - driver for parallels hypervisor
  - Various LXC improvements
  - Add virDomainGetHostname
  - Drop upstream patches
    4036aa91-systemd.patch
    6039a2cb-CVE-2012-3445.patch
* Fri Aug 31 2012 jfehlig@suse.com
- Fix xen driver following changes to make it stateful
  f781e276-xen-driver-fix.patch
  bnc#778006
* Wed Aug  8 2012 jfehlig@suse.com
- Update to libvirt 0.9.13
  - S390: support for s390(x)
  - snapshot: implement new APIs for esx and vbox
  - snapshot: new query APIs and many improvements
  - virsh: Allow users to reedit rejected XML
  - nwfilter: add DHCP snooping
  - storage backend: Add RBD (RADOS Block Device) support
  - sVirt support for LXC domains inprovement
  - Drop upstream patches
    0dda594d-libvirtd-shutdown-deadlock.patch
    9c77bf04-fix-virnetserver-refcnt.patch
    57349ffc-lxc-ctrl.patch
    revert-d8978c90.patch
* Tue Aug  7 2012 jfehlig@suse.com
  _ Update to libvirt 0.9.12
  - qemu: allow snapshotting of sheepdog and rbd disks
  - blockjob: add new AP
  - many bug fixes and improvements
* Wed Aug  1 2012 jfehlig@suse.com
- daemon: Fix crash in virTypedParameterArrayClear
  CVE-2012-3445
  6039a2cb-CVE-2012-3445.patch
  bnc#773955
* Tue Jul 10 2012 jfehlig@suse.com
- libvirtd.service: ensure libvirtd starts after network
  4036aa91-systemd.patch
  bnc#767932
* Fri Jun 22 2012 jfehlig@suse.com
- Add upstream patch to fix ref count of virNetServer object
  9c77bf04-fix-virnetserver-refcnt.patch
* Thu Jun 21 2012 jfehlig@suse.com
- Fix libvirtd deadlock on shutdown
  0dda594d-libvirtd-shutdown-deadlock.patch
  bnc#767797
* Thu Jun 21 2012 jfehlig@suse.com
- Fix segfault in libvirt_lxc
  57349ffc-lxc-ctrl.patch
  bnc#767448
* Wed Jun 20 2012 jfehlig@suse.com
- Fix build on i586
  revert-d8978c90.patch
* Tue Jun 19 2012 jfehlig@suse.com
- Update to libvirt 0.9.11.4 stable release
* Tue Jun 12 2012 jfehlig@suse.com
- VUL-1: Fix hotplug support for usb devices with same vendorID,
  productID
  9914477e-usb-search-funcs.patch
  05abd150-usb-improve-hotplug.patch
  bnc#766559
* Wed May 30 2012 jfehlig@suse.com
- Add capability 'audit_write' to libvirtd apparmor profile
  update install-apparmor-profiles.patch
  bnc#764388
- Update to libvirt 0.9.11.3 stable release
* Wed Apr 25 2012 jfehlig@suse.com
- Copy user in virURIParse
  4eb1c256-viruri-user.patch
  bnc#757766
* Wed Apr 25 2012 jfehlig@suse.com
- yajl is availabile in all supported SUSE products, so always
  use it when building libvirtd
* Thu Apr 12 2012 jfehlig@suse.com
- Update to libvirt 0.9.11
  - Add support for the suspend event
  - Add support for event tray moved of removable disks
  - qemu: Support numad
  - cpustats: API, improvements and qemu support
  - qemu: support type='hostdev' network devices at domain start
  - Introduce virDomainPMWakeup API
  - network: support Open vSwitch
  - snapshot improvements
* Mon Mar 26 2012 jfehlig@suse.com
- Remove unconditional define of 'with_netcontrol'
* Thu Feb 16 2012 jfehlig@suse.com
- Add a note in /etc/libvirt/qemu.conf describing administrator
  vigilance required when enabling a lock manager such as sanlock
* Thu Feb 16 2012 jfehlig@suse.com
- Recommend dmidecode if suse_version > 1110.  dmidecode is used
  by virConnectGetSysinfo.
* Thu Feb 16 2012 jfehlig@suse.com
- Add upstream patches to fix issues with older PolicyKit
  c05ec920-polkit0-build.patch
  fcdfa31f-polkit0-auth.patch
* Wed Feb 15 2012 jfehlig@suse.com
- Update to libvirt 0.9.10
  - Add support for sVirt in the LXC driver
  - Add new API virDomainBlockRebase
  - Add api to set and get domain metadata
  - virDomainGetDiskErrors public API
  - Add rawio attribute to disk element of domain XML
  - Introduce virDomainPMSuspendForDuration API
  - Add virStorageVolResize() API
  - Add a virt-host-validate command to sanity check HV config
  - Add new virDomainShutdownFlags API
  - QEMU guest agent support
* Wed Feb  8 2012 jfehlig@suse.com
- Fix libvirtd apparmor profile to work with libxenlight toolstack
  Updated install-apparmor-profiles.patch
  bnc#745890
* Wed Jan 25 2012 jfehlig@suse.com
- Fix init script packaging after enabling systemd support
* Tue Jan 24 2012 jfehlig@suse.com
- Fix %%files after enabling sanlock support
* Wed Jan 18 2012 jfehlig@suse.com
- Enable libvirt integration with sanlock
* Wed Jan 11 2012 jfehlig@suse.com
- During configure, libvirt checks for availability of iptables
  binary and doesn't actually use anything from iptables-devel
  package, hence only need 'BuildRequires: iptables'.
* Mon Jan  9 2012 jfehlig@suse.com
- Update to libvirt 0.9.9
  - Add new API virDomain{S,G}etInterfaceParameters
  - Add new API virDomain{G,S}etNumaParameters
  - Add support for ppc64 qemu
  - Support Xen domctl v8
* Wed Jan  4 2012 jfehlig@suse.com
- Fixup systemd support as per openSUSE systemd packaging
  guidelines.
* Tue Jan  3 2012 jfehlig@suse.com
- Use %%fdupes for duplicate file checking instead of hand-rolled
  function
* Thu Dec 15 2011 jfehlig@suse.com
- CVE-2011-4600: unintended firewall port exposure after restarting
  libvirtd when defining a bridged forward-mode network
  ae1232b2-CVE-2011-4600.patch
  bnc#736082
- Post-0.9.8 upstream systemd patches
  10404671-systemd-build-fix.patch 478a4d07-systemd-build-fix.patch
- Update to libvirt 0.9.8
  - Add support for QEMU 1.0
  - Add first parts of PPC cpu driver
  - Add new API virDomain{Set, Get}BlockIoTune
  - block_resize: Define the new API
  - Add a public API to invoke suspend/resume on the host
  - Various improvements for LXC containers
  - Define keepalive protocol and add virConnectIsAlive API
  - Add support for STP and VLANfiltering
  - Numerous bug fixes and improvements
* Wed Dec 14 2011 jfehlig@suse.com
- Add support for QEMU 1.0
  dd8e8956-qemu-1.0.patch
  bnc#736569
* Wed Nov 30 2011 jfehlig@suse.com
- Allow qemu driver (and hence libvirtd) to load when qemu
  user:group does not exist.  The kvm or qemu package, which may
  not exist on a xen host, creates qemu user:group.
  relax-qemu-usergroup-check.patch
* Mon Nov 28 2011 jfehlig@suse.com
- Handle empty strings in s-expression returned by xend
  a495365d-sexpr-empty-str.patch
  bnc#731344
- Allow libvirtd to access libvirt_{io,part}helper when confined
  by apparmor
  Update install-apparmor-profiles.patch
  bnc#730435
* Mon Nov 21 2011 jfehlig@suse.com
- Accommodate Xen domctl version 8
  xen-domctl-ver8.patch
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Nov 15 2011 jfehlig@suse.com
- Fix build when using older PolicyKit
  d47ab3fe-polkit0.patch
* Thu Nov 10 2011 jfehlig@suse.com
- Update to libvirt 0.9.7
  - esx: support vSphere 5.x
  - vbox: support for VirtualBox 4.1
  - Introduce the virDomainOpenGraphics API
  - Add AHCI support to qemu driver
  - snapshot: many improvements and 2 new APIs
  - api: Add public api for 'reset'
* Tue Oct 18 2011 jfehlig@suse.com
- Add AHCI controller support to qemu driver
  c1bc3d89-qemu-add-ahci.patch
- Set security driver to 'none' in /etc/libvirt/qemu.conf.  Users
  must opt-in for Apparmor confinement of qemu instances.
  suse-qemu-conf.patch
* Fri Sep 23 2011 jfehlig@suse.com
- Revert upstream commit f84aedad, which is not needed since
  affected SUSE kvm packages have the necessary qemu fix
  f84aedad-revert.patch
* Fri Sep 23 2011 jfehlig@suse.com
- Update to libvirt 0.9.6
  - Fix shutdown regression with buggy qemu
* Wed Sep 21 2011 andrea.turrini@gmail.com
- Fixed typos in libvirt.spec
* Tue Sep 20 2011 jfehlig@suse.com
- Update to libvirt 0.9.5
  - many snapshot improvements
  - latency: Define new public API and structure
  - USB2 and various USB improvements
  - storage: Add fs pool formatting
  - Add public API for getting migration speed
  - Add basic driver for Microsoft Hyper-V
  - Many bug fixes and improvements
* Fri Sep 16 2011 jfehlig@suse.com
- Enable building with libnetcontrol
* Fri Sep 16 2011 jengelh@medozas.de
- Select libnl-1_1-devel
* Wed Sep 14 2011 jfehlig@suse.com
- Set qemu migration speed unlimited when migrating to file
  7e5f6a51-rpc-generator.patch b12354be-mig-speed-1.patch
  1282bd80-mig-speed-2.patch 6f84e110-mig-speed-3.patch
  829bce17-mig-speed-4.patch 8fc40c51-mig-speed-5.patch
  ef1065cf-mig-speed-6.patch 0257ba8f-mig-speed-7.patch
  bnc#706436
* Wed Sep 14 2011 jfehlig@suse.com
- Increase max size of buffer used to receive xend response
  57c95175-xend-buff-size.patch
- Don't overwrite useful error messages in legacy xen driver
  32620dab-fix-xen-err-msg.patch
  bnc#711096
* Wed Sep 14 2011 jfehlig@suse.com
- Add upstream patches to stop excessive logging
  7f2498ef-no-log-invalid.patch 6ff9fc26-quiet-libxl-logging.patch
* Wed Sep 14 2011 jfehlig@suse.com
- Add 'Conflicts: kvm < 0.14.1' to ensure libvirt is using a
  kvm package that creates qemu user:group.  Remove user:group
  creation from libvirt
  bnc#694883
- Add libvirt group at package installation
  bnc#694885
* Thu Sep  8 2011 jfehlig@suse.com
- Explicitly add 'BuildRequires: libgcrypt-devel' since it is no
  longer required by libgnutls-devel
* Thu Sep  8 2011 jfehlig@suse.com
- netcf is buggy and not well maintained in SUSE.  Disable it in
  libvirt
* Thu Sep  8 2011 jfehlig@suse.com
- polkit support was mistakenly disabled, re-enable
* Thu Aug 25 2011 jfehlig@novell.com
- Add cgconfig to Should-{Start,Stop} in libvirtd init script
  bnc#712245
* Fri Aug 19 2011 jfehlig@suse.com
- Fix apparmor profile location and content
  update install-apparmor-profiles.patch
  bnc#705668
* Wed Aug 17 2011 jfehlig@suse.com
- Fix libvirtd SIGHUP handler
  9e093f0b-libvirtd-sighup.patch
* Wed Aug 17 2011 dmueller@suse.de
- add baselibs.conf to sources
* Mon Aug  8 2011 jfehlig@suse.com
- Enable apparmor security dirver, SLES bnc#705668
  install-apparmor-profiles.patch
* Thu Aug  4 2011 jfehlig@suse.com
- Update to libvirt 0.9.4
  - bandwidth QoS control
  - Add new API virDomainBlockPull*
  - save: new API to manipulate save file images
  - CPU bandwidth limits support
  - allow to send NMI and key event to guests
  - new API virDomainUndefineFlags
  - Implement code to attach to external QEMU instances
  - various missing python binding
  - bios: Add support for SGA
  - Numerous improvements and documentation / bug fixes
* Wed Jul 13 2011 jfehlig@suse.de
- Add some upstream patches to fix memory leaks and some bugs
  in new rpc code
  c2ddd536-cert-key-order.patch 3e5d48ef-rpc-1.patch
  927dfcf6-rpc-2.patch 2c85644b-rpc-3.patch afe8839f-rpc-4.patch
  3cfdc57b-rpc-5.patch 7518ad75-remote-mem-leak.patch
  a34e193f-statstest.patch 41828514-skip-xen-tests.patch
  eb314315-pv-kernel-cmdline.patch 00d3c5a6-remove-dead-code.patch
  b8adfcc6-fix-polkit0-build.patch b2534529-unused-param.patch
* Tue Jul  5 2011 jfehlig@suse.de
- Update to libvirt 0.9.3
  - vcpupin: introduce the new libvirt API (virDomainGetVcpupinInfo)
  - Add TXT record support for virtual DNS service
  - Support reboots with the QEMU driver
  - Introduce virDomainGetControlInfo API
  - virNodeGetMemoryStats: Expose new API
  - virNodeGetCPUTime: Implement public API
  - send-key: Defining the public API
  - vcpupin: introduce a new libvirt API (virDomainPinVcpuFlags)
  - support multifunction PCI device
  - lxc: various improvements
* Fri Jul  1 2011 jfehlig@suse.de
- Create qemu user:group if necessary at package installation.
  More fallout from bnc#694883
* Thu Jun 30 2011 jfehlig@suse.de
- VUL-0: libvirt: integer overflow in VirDomainGetVcpus
  774b21c1-CVE-2011-2511.patch
  bnc#703084
* Thu Jun 30 2011 jfehlig@suse.de
- Enable building libvirt with audit support
  bnc#694891
* Mon Jun 13 2011 lidongyang@novell.com
- fate#311371 Enhance yast to configure live migration for
  Xen and KVM
  add firewall service file for libvirt
* Thu Jun  9 2011 jfehlig@suse.de
- Invoke qemu instances as user:group qemu:qemu by default
  bnc#694883
* Mon Jun  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.2
  - Framework for lock manager plugins
  - API for network config change transactions (netcf required)
  - flags for setting memory parameters
  - virDomainGetState public API
  - qemu: allow blkstat/blkinfo calls during migration
  - Introduce migration v3 API
  - Defining the Screenshot public API
  - public API for NMI injection
- spec file: Adjust some directory attributes to support running
  non-privileged qemu instances
* Sun May 15 2011 jfehlig@suse.de
- Remove vi_VN locale if suse_version < 11.3
* Thu May 12 2011 fcrozat@suse.com
- Enable cap_ng when building lxc support.
* Fri May  6 2011 jfehlig@suse.de
- Update to libvirt 0.9.1
  - support various persistent domain updates
  - improvements on memory APIs
  - Add virDomainEventRebootNew
  - various improvements to libxl drive
  - Spice: support audio, images and stream compression
* Tue Apr 12 2011 jfehlig@suse.de
- Move libvirt-iohelper from client to base package
* Tue Apr 12 2011 coolo@opensuse.org
- fix baselibs.conf not to requires source 32bit
* Mon Apr 11 2011 jfehlig@suse.de
- Install log dir for libxl
  f7e9b448-libxl-build.patch
* Mon Apr  4 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 final
  - Support cpu usage tuning
  - Add public APIs for storage volume upload/download
  - Add public API for setting migration speed on the fly
  - Add libxenlight driver
  - qemu: support migration to fd
  - add virDomain{Get,Set}BlkioParameters
  - introduce a new libvirt API (virDomainSetMemoryFlags)
  - Expose event loop implementation as a public API
  - Dump the debug buffer to libvirtd.log on fatal signal
  - Audit support
  - Numerous enhancements and bug fixes
* Thu Mar 31 2011 jfehlig@novell.com
- Update to libvirt 0.9.0 RC3
* Thu Mar 24 2011 coolo@novell.com
- use %%first_lang before changing symlinks, find_lang removes
  unsupported languages
* Tue Mar 15 2011 jfehlig@novell.com
- VUL-0: libvirt: several API calls do not honour read-only
  connection
  71753cb7-CVE-2011-1146.patch
  bnc#678406
* Mon Mar  7 2011 jfehlig@novell.com
- Add baselibs.conf file to build xxbit packages
  for multilib support
  bnc#676921
* Fri Feb 25 2011 jfehlig@novell.com
- Minor fixes for libvirt-guests
  bnc#653398
* Fri Feb 18 2011 jfehlig@novell.com
- Do not add drive 'boot=on' param when a kernel is specified
  efc2594b-boot-param.patch
* Thu Feb 17 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 final
  - sysinfo: expose new API
  - cgroup blkio weight support
  - smartcard device support
  - qemu: Support per-device boot ordering
* Tue Feb 15 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC3
* Fri Feb 11 2011 jfehlig@novell.com
- Update to libvirt 0.8.8 RC1
* Mon Jan 31 2011 jfehlig@novell.com
- Remove explicit dependency on libyajl
  libvirt.spec
  bnc#668225
* Fri Jan 21 2011 jfehlig@novell.com
- Retry JSON monitor 'cont' cmd on MigrationExpected error
  4301b95a-json-cont-cmd.patch
* Tue Jan 18 2011 jfehlig@novell.com
- Add support for specifying Hardware Assisted Paging (HAP) in
  libvirt domain XML.
  48a5dccd-hap1.patch
  04197350-hap2.patch
  af521a01-hap3.patch
  79f56c66-hap4.patch
  094c6f4a-hap-fix.patch
  bnc#659665
* Tue Jan 18 2011 jfehlig@novell.com
- Enabled yajl for suse_version >= 1140
* Fri Jan 14 2011 jfehlig@novell.com
- Fix generation of dnsmasq's --dhcp-hostsfile option
  a43c7338-dnsmasq-hostfile-fix.patch
- Disable yajl support as the library does not yet exist in
  SuSE distros.
* Tue Jan 11 2011 jfehlig@novell.com
- Support libvirt-guests on SuSE distros
  use-libvirt-guests-on-suse.patch
  bnc#653398
* Mon Jan  3 2011 jfehlig@novell.com
- Update to libvirt 0.8.7
  - Preliminary support for VirtualBox 4.0
  - IPv6 support
  - Add VMware Workstation and Player driver
  - Add network disk support
* Wed Dec 22 2010 jfehlig@novell.com
- Fix VNC port reservation race in qemu driver
  c58b1056-init-bitmap-size.patch
  bnc#659431
* Fri Dec 10 2010 jfehlig@novell.com
- Do not limit insserv_cleanup to SLES
* Thu Dec  9 2010 jfehlig@novell.com
- disable building openvz driver
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.6
  - new API virDomainIsUpdated
  - Add support for iSCSI target auto-discovery
  - QED: Basic support for QED images
  - Introduce a virDomainOpenConsole API
  - Support for SPICE graphics
  - Add a sysinfo and SMBIOS support
  - Implement virsh qemu-monitor-command
- Enabled yajl, macvtap, and virtualport for suse_version >= 1140
* Mon Nov  1 2010 jfehlig@novell.com
- Fix build when using "policy kit 0"
  polkit0.patch
* Mon Nov  1 2010 jfehlig@novell.com
- Update to libvirt 0.8.5
  - Enable JSON and netdev features in QEMU > 0.13
  - framework for auditing integration
  - framework for DTrace/SystemTap integration
  - Setting the number of vcpu at boot
  - Enable support for nested SVM
  - Virtio plan9fs filesystem QEMU
  - Memory parameter controls
  - portability to OS-X
  - lot of bug fixes and other improvements
* Wed Oct 13 2010 jfehlig@novell.com
- cannot restart dead libvirtd without manually removing pidfile
  modified libvirtd.init
  bnc#645755
* Mon Oct 11 2010 cristian.rodriguez@opensuse.org
- Fix package dependencies so can be installed without
  pulling excess of optional components
* Tue Oct  5 2010 cristian.rodriguez@opensuse.org
- Support dropping capabilities with cap-ng library in
  openSUSE >= 11.3
* Tue Sep 28 2010 jfehlig@novell.com
- Fix build when virtualport support is available but macvtap is
  disabled.
  vport-configure.patch
* Thu Sep 23 2010 jfehlig@novell.com
- Fix CDROM media change for Xen PV domains
  modified xen-pv-cdrom.patch
  bnc#636231
* Fri Sep 10 2010 jfehlig@novell.com
- Update to libvirt 0.8.4
  - various improvements to UML driver
  - documentation improvements
  - lot of bug fixes and other improvements
  - enable ESX driver for openSUSE
* Sat Aug  7 2010 jfehlig@novell.com
- Update to libvirt 0.8.3
  - Support vSphere 4.1
  - Qemu arbitrary monitor commands
  - Qemu Monitor API entry point
  - lots of improvements and bug fixes
* Fri Jul  9 2010 jfehlig@novell.com
- VUL-0: multiple issues in libvirt
  CVE-2010-223x-000[1-0].patch, CVE-2010-223x-0010.patch,
  CVE-2010-2242-nat.patch
  bnc#618155
* Fri Jun 25 2010 jfehlig@novell.com
- Use netcat-openbsd, which contains a proper 'nc' program
  supporting the '-U' option.  Drop socat.patch.
  bnc#611023
* Mon Jun 21 2010 jfehlig@novell.com
- Re-enable numa support now that bnc#598488 is resolved.
* Fri Jun  4 2010 jfehlig@novell.com
- Allocate buffer to hold xend content
  bnc#609738
  xend-buff-size.patch
- Add upstream fixes to bitmap code that was introduced to fix
  bnc#594024
  bitmap-alloc.patch
  bitmap-fixes.patch
* Tue Jun  1 2010 jfehlig@novell.com
- Fix race in VNC port reservation with qemu/KVM domains
  bnc#594024
  vnc-race-{1,2,3}.patch
* Wed May 12 2010 jfehlig@novell.com
- Don't package directories/files under /var/run
- Add upstream commit 34a7f3f6 to fix unintentional breakage of
  RPC protocol.
- Disable numa support in openSUSE11.3/Factory pending resolution
  of bnc#598488
* Fri Apr 30 2010 jfehlig@novell.com
- Update to libvirt 0.8.1
  - Add virDomainGetBlockInfo API to query disk sizing
  - Start dnsmasq from libvirtd with --dhcp-hostsfile option
  - lots of improvements and bug fixes
* Tue Apr 13 2010 jfehlig@novell.com
- Update to libvirt 0.8.0
  - Snapshot API framework
  - Add managed save API entry points
  - Timer subselection for domain clock
  - Add hook utilities
  - Network filtering API
  - Introduce a new virDomainUpdateDeviceFlags public API
  - Introduce a new public API for domain events
  - Public virDomainMigrateSetMaxDowntime API
  - Add public API for volume wiping
  - xenapi: Initial commit of the new driver
  - lots of improvements and bug fixes
* Fri Mar 26 2010 jfehlig@novell.com
- Fix 'virsh dominfo' crash when no security driver is configured
  fix-no-secdriver.patch
* Mon Mar 22 2010 jfehlig@novell.com
- Updated to version 0.7.7
  - Introduce public API for domain async job handling
  - macvtap support
  - Add QEMU support for virtio channel
  - Add persistence of PCI addresses to QEMU
  - Functions for computing baseline CPU from a set of host CPUs
  - Public API for virDomain{Attach,Detach}DeviceFlags
  - lots of improvements and bug fixes
* Tue Mar  9 2010 jfehlig@novell.com
- Ensure yast-created bridges are not manipulated by libvirt
  bnc#584757
  Modified suse-network.patch
* Thu Mar  4 2010 jfehlig@novell.com
- Fix ordering of xen disks to preserve 'bootable' flag
  bnc#474738
  xend-disk-order.patch
- Add support for blktap2 disks
  xen-tap2-support.patch
* Mon Mar  1 2010 jfehlig@novell.com
- Fix listing of yast-created bridges
  bnc#583754
  Modified suse-network.patch
* Mon Feb 22 2010 jfehlig@novell.com
- Add support for new XEN_DOMCTL_INTERFACE_VERSION version 7.
  xen-domctl-ver7.patch
* Mon Feb 15 2010 jfehlig@novell.com
- Unconditionally add /var/log/libvirt/{qemu,lxc,uml} directories.
  bnc#579522
* Thu Feb  4 2010 jfehlig@novell.com
- Updated to version 0.7.6
  - Implement support for multi IQN
  - Implement CPU topology support for QEMU driver
  - Use QEmu new device adressing when possible
  - Implement SCSI controller hotplug/unplug for QEMU
  - lots of improvements and bug fixes
* Thu Jan 28 2010 jfehlig@novell.com
- Support new XEN_SYSCTL_INTERFACE_VERSION 7 in libvirt
  bnc#574124
  xen-sysctl-v7.patch
- Add upstream patches as prelude to fixing various device
  attach/detach issues
  devflag-0[1-9].patch
- Fix attaching/detaching disk device from inactive Xen guest
  bnc#500586 and bnc#573748
* Tue Jan 12 2010 jfehlig@novell.com
- Fix migration with Xen4.0
  bnc#569598
  Add xen-migration-params.patch
  Remove migrate-params.patch
* Thu Jan  7 2010 jfehlig@novell.com
- Fix freeing of uninitialized pointer when using HAL in
  node device driver
  node-dev-free.patch
* Mon Jan  4 2010 jfehlig@novell.com
- Require virt-utils package for common tools such as qemu-img
* Tue Dec 29 2009 jfehlig@novell.com
- Updated to version 0.7.5
  - Add new API virDomainMemoryStats to header and drivers
  - Public API and domain extension for CPU flags
  - expose SR IOV physical/virtual function relationships
  - Support for JSON mode monitor [deactivated]
  - Support for interface model='netfront'
  - vbox: Add support for version 3.1
  - Support QEMU's virtual FAT block device driver
  - lots of improvements and bug fixes
- Fix libvirt xen hypervisor driver to work with domctl interface
  version 6
  xen-shr-pages.patch
* Mon Dec  7 2009 jfehlig@novell.com
- Plumb domain description in xend backend
  xend-description-tag.patch
* Wed Nov 25 2009 jfehlig@novell.com
- Fix listing of defined but inactive Xen domains
  xen-list-defined.patch
* Tue Nov 24 2009 jfehlig@novell.com
- Updated to version 0.7.4
  - Implement a node device backend using libudev
  - New APIs for checking some object properties
  - Fully asynchronous monitor I/O processing
  - add MAC address based port filtering to qemu
  - support for IPv6 / multiple addresses per interfaces
  - lots of improvements and bug fixes
* Thu Nov 19 2009 jfehlig@novell.com
- Fix compilation against xen-unstable
  xen-max-vcpus.patch
- Modify detach-disk.patch as per upstream suggestions
* Thu Nov  5 2009 jfehlig@novell.com
- spec file: Fix polkit vs PolicyKit Requires
* Mon Oct 19 2009 jfehlig@novell.com
- Fix compilation when selinux is enabled
  selinux-ldflags.patch
- Fix compilation warnings
  updated snapshots.patch
  virsh-warning.patch
* Fri Oct 16 2009 jfehlig@novell.com
- Updated to version 0.7.2
  - sVirt AppArmor security driver
  - Add public API definition for data stream handling
  - ESX add esxDomainDefineXML()
  - LXC: suspend/resume support
  - Big code tree cleanup
  - Lots of bug fixes and improvements
* Tue Oct 13 2009 jfehlig@novell.com
- Add ocfs2 to list of supported fs pool types
  fate#307387
* Tue Oct 13 2009 jfehlig@novell.com
- Build phyp driver ifarch ppc64
  fate#307096
- Fix memory leaks in libvirtd's message processing
  msg-proc-memleak.patch
* Tue Sep 29 2009 jfehlig@novell.com
- Fix connection ref counting in xen drivers
  xen-refcnt.patch
* Fri Sep 25 2009 jfehlig@novell.com
- Fix abort in virsh when specifying a connection URI
  vshdeinit-recurse.patch
* Wed Sep 23 2009 jfehlig@novell.com
- Workaround for missing pkgconfig file in device-mapper-devel
  devmap-no-pkgconfig.patch
  bnc#540942
* Mon Sep 21 2009 jfehlig@novell.com
- Updated to version 0.7.1
  - Add support for encrypted (qcow) volume creation
  - Secret manipulation public API
  - Multipath storage support module
  - VBox add Storage Volume support
  - Support configuration of huge pages in guests
  - Support new PolicyKit 1.0 API
  - Compressed save image format for Qemu
  - Qemu add host PCI device hotplug support
* Wed Aug 26 2009 jfehlig@novell.com
- Updated to version 0.7.0
  - Interface implementation based on netcf (disabled on SuSE)
  - Add new net filesystem glusterfs
  - Initial VMWare ESX driver
  - Add support for VBox 3 and event callbacks on vbox
  - First version of the Power Hypervisor driver
  - Run QEMU guests as an unprivileged user (still root on SuSE)
  - Support cgroups in QEMU driver
  - QEmu hotplug NIC support
  - Storage cloning for LVM and Disk backends
* Tue Jul  7 2009 jfehlig@novell.com
- Updated to version 0.6.5
  - create storage volumes on disk backend
  - drop of capabilities based on libcap-ng when possible
  - forbid autostart on transcient networks
  - re-detection of transient VMs after libvirtd restart
  - create and destroy NPIV support
  - other bug fixes and cleanups
* Fri Apr 24 2009 jfehlig@novell.com
- Removed unnecessary call to fillup_and_insserv macro in
  %%post scriptlet
* Wed Apr 22 2009 jfehlig@novell.com
- Updated to version 0.6.2
  - support SASL auth for VNC server
  - memory ballooning in QEMU
  - SCSI HBA storage pool support
  - PCI passthrough in Xen driver
  - new APIs for Node device detach reattach and reset
  - sVirt mandatory access control support
  - thread safety of the API and event handling
  - allow QEmu domains to survive daemon restart
  - extended logging capabilities
  - support copy-on-write storage volumes
  - support of storage cache control options for QEMU/KVM
- Improvements from lnussel@suse.de
  - add %%jobs macro again
  - package default qemu network and augeas config files again
  - don't start libvirtd by default (bnc#496838)
* Mon Apr 20 2009 crrodriguez@suse.de
- use --disable-static instead of just removing static libraries
* Fri Jan 30 2009 jfehlig@novell.com
- Fix build for architectures not supporting numa
- Forward port suse-network.patch and snapshots.patch
* Wed Jan 28 2009 jfehlig@novell.com
- Updated to version 0.5.1
  - CPU and scheduler support for LXC
  - SDL display configuration
  - domain lifecycle event support for QEmu and Xen with python
    bindings
  - KVM/QEmu migration support
  - User Mode Linux driver
  - API for node device enumeration using HAL and DeviceKit with
    python bindings
  - Many bug fixes and improvements
* Fri Jan  9 2009 jfehlig@novell.com
- Added missing html and png files to libvirt-doc package
  devhelp.patch
  bnc#463810
* Mon Dec 15 2008 jfehlig@novell.com
- Patch for CVE-2008-5086
  bnc#459009
* Fri Dec  5 2008 jfehlig@novell.com
- Fix migration of Xen domains
  bnc#456946
* Tue Dec  2 2008 jfehlig@novell.com
- Refresh xen-maxmem.patch to match upstream
  bnc#431766
* Tue Nov 25 2008 jfehlig@novell.com
- Add network to Required-Start in libvirtd init script
  bnc#448756
* Mon Nov 24 2008 jfehlig@novell.com
- Fix connecting/disconnecting ISO via virt-manager
  bnc#446773
* Fri Nov 21 2008 jfehlig@novell.com
- Fix detach of Xen tap devices
  bnc#410644 and bnc#411633
* Fri Nov  7 2008 jfehlig@novell.com
- Fix handling of iso/cdrom for xen pv domains.
  bnc#437388
* Wed Nov  5 2008 jfehlig@novell.com
- Expose networks managed outside of libvirt as read-only.
  bnc#441633
* Wed Nov  5 2008 jfehlig@novell.com
- Fix vnc port assignement in domain XML
  bnc#441625
* Thu Oct 23 2008 jfehlig@novell.com
- Add upstream patches to fix ordering problem with setting up
  cgroup containment on LXC domains.
  bnc#437816
* Mon Oct 20 2008 jfehlig@novell.com
- Remove IA64 from list of architectures supporting Xen.
* Fri Oct 10 2008 jfehlig@novell.com
- Added upstream patches providing additional LXC support
  bnc#433881
* Mon Oct  6 2008 jfehlig@novell.com
- Use xend vs hypercall interface to change max mem setting
  bnc#431766
* Wed Oct  1 2008 jfehlig@novell.com
- Enabled libvirtd listen mode in libvirtd init script.
* Wed Oct  1 2008 jfehlig@novell.com
- Updated to version 0.4.6
  - avoid a segfault if missing qemu emulator
  - reading vncdisplay from xend domain
  - segfault in OpenVZ
  - fix parsing of pool without a source
- Fixed bug in network interface parsing
  - vif-parsing.patch submitted upstream
* Tue Sep 16 2008 jfehlig@novell.com
- open-iscsi package required for iscsi storage backend
* Mon Sep 15 2008 jfehlig@novell.com
- Updated to version 0.4.5
  - NETNS support for Linux containers
  - unified XML domain and network parsing for all drivers
  - OpenVZ features improvements
  - OpenVZ and Linux containers support now default
  - USB device passthrough for QEmu/KVM
  - storage pool source discovery
  - other bug fixes and improvements
* Thu Sep  4 2008 kwolf@suse.de
- Added Python bindings for the snapshot functions
* Wed Sep  3 2008 kwolf@suse.de
- Implemented listing of snapshots for Xen and in virsh
* Tue Sep  2 2008 kwolf@suse.de
- Added snapshot support. Implemented snapshot_create/apply/delete
  for Xen.
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in nfs storage pool creation/deletion
* Fri Aug 29 2008 jfehlig@novell.com
- Fixed bugs in LVM storage pool creation.
  logical-storage-driver.patch submitted upstream
* Wed Aug 27 2008 jfehlig@novell.com
- Changed mDNS advertisement of libvirtd service to disabled by
  default.  Enable in libvirtd.conf.
- Disable libvirtd from listening on TLS socket by default.  User
  must enable after setting up CA and issuing certificates.
* Mon Aug 25 2008 jfehlig@novell.com
- Enabled iscsi storage driver support
- Enabled ssh transport using socat.  SuSE's version of netcat
  does not support connecting to UDS.
- Fixed spec file breakage due to SELinux enablement
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Tue Aug 12 2008 jfehlig@novell.com
- Cleanup of libvirtd init script
- Removed dnsmasq from BuildRequires
* Sat Aug  9 2008 jfehlig@novell.com
- Adjustments to spec file
  + Added /var/lib/libvirt directory
  + Enabled LXC support if suse_version > 1100, fate #304001
  + Cleaned up some rpmlint warnings
* Sun Jul  6 2008 jfehlig@novell.com
- Updated to libvirt 0.4.4
  + Bug fixes: QEmu network serialization, internal memory allocation
    fixes, virsh large file config problem, xen list APIs when max is
    zero, string escape problems in the xm driver
  + Improvements: add autogen to tarballs, improve iSCSI support
  + Cleanups: const-ness fixed, string helpers for enumeations
- spec file adjustments
  + Remove ExclusiveArch
  + Common spec file for all products
  + Support for building/running without Xen
* Fri May  9 2008 jfehlig@novell.com
- Adjust libvirtd PolicyKit configuration file to match standard
  suse procedures.  bnc#388769
* Mon May  5 2008 jfehlig@novell.com
- Fix path to iptables.  bnc#386280
* Thu Apr 24 2008 jfehlig@novell.com
- Fix Xen 3.2 hypercalls.  bnc#378798
* Thu Apr 10 2008 jfehlig@novell.com
- Fix NULL pointer dereference in auth callback.  bnc#373180,
  bnc#354995
* Wed Jan  9 2008 jfehlig@novell.com
- Remove Requires of nc package.  netcat is the equivalent but it
  does not support unix domain sockets so no need to require it
  either.
* Tue Jan  8 2008 coolo@suse.de
- do not require a non existant package, but change it to a recommend
  to digestmd5
* Fri Jan  4 2008 jfehlig@novell.com
- Updated to libvirt-0.4.0
  - SASL based authentication for libvirt remote support
  - PolicyKit authentication
  - Documentation: example files for QEMU and libvirtd configuations,
    authentication documentation updates
  - Bug fixes, improvements and code cleanup
* Tue Oct  9 2007 jfehlig@novell.com
- Updated to libvirt 0.3.3
  - Avahi mDNS daemon export
  - NUMA support
  - Bug fixes
- Cleanup rpmlint warnings
* Mon Oct  8 2007 jfehlig@novell.com
- Removed 'jobs' option from make invocation in spec file.  Appears
  to be a subtle dependency issue in one of the makefiles which is
  causing problems with generation of python bindings when jobs > 1.
  Bug #329032.
* Mon Aug 20 2007 jfehlig@novell.com
- Added init script for libvirtd.  libvirtd is needed to support
  management of qemu/kvm guests.  Some Xen networking is handled
  through libvirt as well - bug #298021.
* Mon Jul 23 2007 jfehlig@novell.com
- Update to libvirt-0.3.0
  - Secure Remote support
  - Documentation: remote support, description of the URI connection
    strings, update of virsh man page, matrix of libvirt API/hypervisor
    support with version informations
  - Bug fixes: examples Makefile.am generation, SetMem fix, URI
    handling and ordering of drivers, fix virsh help without hypervisor,
    id marshalling fix, fix virConnectGetMaxVcpus on remote, avoid
    a realloc leak, scheduler parameters handling for Xen, various
    early remote bug fixes, remove virsh leaks of domains references,
    configCache refill bug, fix XML serialization bugs
  - Improvements: QEmu switch to XDR-based protocol, device attach/detach
    commands OCaml bindings, new entry points virDomainGetConnect and
    virNetworkGetConnect useful for bindings, reunitifaction of remote
    and qemu daemon under a single libvirtd with a config file
  - Cleanups: parsing of connection URIs, messages from virsh,
    Coverage files, Solaris fixes, avoid [r]index calls, release
    information in Xen backend, virsh cpupin command cleanups,
    xen:/// suppport as standard Xen URI, improve driver
    selection/decline mechanism, error reporting on XML dump,
    Remove unused virDomainKernel structure, daemon event loop event
    handling, various unifications cleanup in the daemon merging,
    internal file and timer monitoring API, remove libsysfs dependancy,
    call brctl program directly, virBuffer functions cleanups,
    make init script LSB compliant, error handling on lookup functions,
    remove internal virGetDomainByID, revamp of xen subdrivers interfaces
  - Localization updates
* Tue Jun 12 2007 ccoffing@novell.com
- Update to libvirt-0.2.3.
- Fix duplicate files found by rpmlint.
* Wed May 23 2007 ccoffing@novell.com
- Fix rpmlint errors.
* Fri Apr 27 2007 ccoffing@novell.com
- Update to libvirt-0.2.2.
* Wed Mar  7 2007 sbrabec@suse.cz
- Created -doc subpackage (#248813).
- Do not remove valid locales.
- Fixed docdir destination.
- Build with CFLAGS.
- Spec file cleanup.
* Tue Feb 20 2007 jfehlig@novell.com
- Removed usr/lib/libvirt_proxy setuid binary from package.  Fixes
  bug #246610.
* Sat Feb 17 2007 jfehlig@novell.com
- Updated to latest release.  Many of the issues seen in virt-manager
  have been caused by bugs / missing functionality in libvirt.  This
  upate provides a better basis for virt-manager.
* Thu Jan 11 2007 jfehlig@novell.com
- Updated to latest release, version 0.1.10.  Submitting to SLES10 SP1
  to provide base functionality for FATE feature 301181.
  - more localizations
  - bug fixes:
  - VCPU info breakages on xen 3.0.3
  - xenDaemonListDomains buffer overflow (Daniel Berrange)
  - reference count bug when creating Xen domains (Daniel Berrange)
  - improvements:
  - support graphic framebuffer for Xen paravirt (Daniel Berrange)
  - VNC listen IP range support (Daniel Berrange)
  - support for default Xen config files and inactive domains of 3.0.4 (Daniel Berrange)
* Fri Dec  8 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.9.
  - python bindings: release interpeter lock when calling C (Daniel Berrange)
  - don't raise HTTP error when looking informations for a domain
  - some refactoring to use the driver for all entry points
  - better error reporting (Daniel Berrange)
  - fix OS reporting when running as non-root
  - provide XML parsing errors
  - extension of the test framework (Daniel Berrange)
  - fix the reconnect regression test
  - python bindings: Domain instances now link to the Connect to avoid garbage collection and disconnect
  - separate the notion of maximum memory and current use at the XML level
  - Fix a memory leak (Daniel Berrange)
  - add support for shareable drives
  - add support for non-bridge style networking configs for guests(Daniel Berrange)
  - python bindings: fix unsigned long marshalling (Daniel Berrange)
  - new config APIs virConfNew() and virConfSetValue() to build configs from scratch
  - hot plug device support based on Michel Ponceau patch
  - added support for inactive domains, new APIs, various associated cleanup (Daniel Berrange)
  - special device model for HVM guests (Daniel Berrange)
  - add API to dump core of domains (but requires a patched xend)
  - pygrub bootloader informations take over <os> informations
  - updated the localization strings
* Fri Oct 20 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.8.
  - Bug for system with page size != 4k
  - vcpu number initialization (Philippe Berthault)
  - don't label crashed domains as shut off (Peter Vetere)
  - fix virsh man page (Noriko Mizumoto)
  - blktapdd support for alternate drivers like blktap (Daniel Berrange)
  - memory leak fixes (xend interface and XML parsing) (Daniel Berrange)
  - compile fix
  - mlock/munlock size fixes (Daniel Berrange)
  - improve error reporting
- Updated to latest release, version 0.1.7.
  - fix a memory bug on getting vcpu informations from xend (Daniel Berrange)
  - fix another problem in the hypercalls change in Xen changeset
    86d26e6ec89b when getting domain informations (Daniel Berrange)
* Tue Sep 26 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.6.  This release includes
  fix in hypercall driver so local patch has been removed.
* Wed Sep 13 2006 jfehlig@novell.com
- Fixed bug in hypercall driver introduced in version 0.1.5.
  Patch sumbmitted upstream and included locally until next release.
* Mon Sep 11 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.5
  - Support for new hypercalls change in Xen changeset 86d26e6ec89b
  - bug fixes: virParseUUID() was wrong, netwoking for paravirt guestsi
    (Daniel Berrange), virsh on non-existent domains (Daniel Berrange),
    string cast bug when handling error in python (Pete Vetere), HTTP
    500 xend error code handling (Pete Vetere and Daniel Berrange)
  - improvements: test suite for SEXPR <-> XML format conversions (Daniel
    Berrange), virsh output regression suite (Daniel Berrange), new environ
    variable VIRSH_DEFAULT_CONNECT_URI for the default URI when connecting
    (Daniel Berrange), graphical console support for paravirt guests
    (Jeremy Katz), parsing of simple Xen config files (with Daniel Berrange),
    early work on defined (not running) domains (Daniel Berrange),
    virsh output improvement (Daniel Berrange
* Mon Aug 28 2006 jfehlig@novell.com
- Updated to latest release, version 0.1.4
  - bug fixes: spec file fix (Mark McLoughlin), error report problem (with
    Hugh Brock), long integer in Python bindings (with Daniel Berrange), XML
    generation bug for CDRom (Daniel Berrange), bug whem using number() XPath
    function (Mark McLoughlin), fix python detection code, remove duplicate
    initialization errors (Daniel Berrange)
  - improvements: UUID in XML description (Peter Vetere), proxy code
    cleanup, virtual CPU and affinity support + virsh support (Michel
    Ponceau, Philippe Berthault, Daniel Berrange), port and tty informations
    for console in XML (Daniel Berrange), added XML dump to driver and proxy
    support (Daniel Berrange), extention of boot options with support for
    floppy and cdrom (Daniel Berrange), features block in XML to report/ask
    PAE, ACPI, APIC for HVM domains (Daniel Berrange), fail saide-effect
    operations when using read-only connection, large improvements to test
    driver (Daniel Berrange)
  - documentation: spelling (Daniel Berrange), test driver examples.
* Wed Aug 16 2006 jfehlig@novell.com
- Added ExclusiveArch tag so as to only build on x86 and x86_64
* Mon Jul 31 2006 jfehlig@novell.com
- initial submission of libvirt package, version 0.1.3
